@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 /**
  * @author Christoph Wurst <christoph@winzerhof-wurst.at>
@@ -20,9 +21,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>
  *
  */
-$app = new \OCA\Mail\AppInfo\Application();
-$app->registerRoutes($this,
-	[
+return [
 	'routes' => [
 		[
 			'name' => 'page#index',
@@ -44,6 +43,11 @@ $app->registerRoutes($this,
 			'url' => '/api/accounts/{accountId}/draft',
 			'verb' => 'POST'
 		],
+		[
+			'name' => 'accounts#updateSignature',
+			'url' => '/api/accounts/{accountId}/signature',
+			'verb' => 'PUT'
+		],
 		[
 			'name' => 'folders#sync',
 			'url' => '/api/accounts/{accountId}/folders/{folderId}/sync',
@@ -104,4 +108,4 @@ $app->registerRoutes($this,
 		'messages' => ['url' => '/api/accounts/{accountId}/folders/{folderId}/messages'],
 		'preferences' => ['url' => '/api/preferences'],
 	]
-]);
+];
