@@ -2,53 +2,8 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Mail",
-    "Loading accounts" : "Indlæser kontoerne...",
-    "Error while loading the accounts." : "Fejl under indlæsning af konti.",
-    "Can not load this folder." : "Kan ikke indlæse denne mappe.",
-    "Searching for {query}" : "Leder efter {query}",
-    "Error while deleting message." : "Fejl under sletning af besked.",
-    "Forwarded message" : "Videresendt besked",
-    "Choose a folder to store the attachment in" : "Vælg den mappe, hvor vedhæftningen skal gemmes i",
-    "Attachments saved to Files." : "Vedhæftning blev gemt i Filer.",
-    "Attachment saved to Files." : "Vedhæftning blev gemt i Filer.",
-    "Error while saving attachments to Files." : "Fejl under lagring af vedhæftninger i Filer.",
-    "Error while saving attachment to Files." : "Fejl under lagring af vedhæftninger i Filer.",
-    "Message flag could not be set." : "Beskedflaget kunne ikke sættes.",
-    "Could not move message." : "Kunne ikke flytte beskeden.",
-    "Invalid account" : "Ugyldig konto",
-    "Invalid folder" : "Ugyldig mappe",
-    "Error while creating the account: " : "Fejl under oprettelse af kontoen:",
-    "Unknown error" : "Ukendt fejl",
-    "All inboxes" : "Alle indbakker",
-    "you" : "dig",
-    "Send message to {email}" : "Send besked til {email}",
-    "Could not load {tag}{name}{endtag}" : "Kunne ikke hente {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Der var et problem med at hente {tag}{name}{endtag}",
-    "{from}\n{subject}" : "{fra}\n{emne}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny besked \nfra {from}","%n nye beskeder \nfra {from}"],
-    "Nextcloud Mail" : "Nextcloud Mail",
-    "Save" : "Gem",
-    "Show all folders" : "Vis all mappe",
-    "Collapse folders" : "Fold mapper sammen",
-    "Error while deleting account." : "Fejl under sletning af kontoen.",
-    "Choose a file to add as attachment" : "Vælg en fil, der skal tilføjes som vedhæftning",
-    "An error occurred while uploading {fname}" : "Der opstod en fejl under uploading af {fname}",
-    "Reply" : "Besvar",
-    "Send" : "Send",
-    "Sending …" : "Sender ...",
-    "Message sent!" : "Beskeden blev sendt!",
-    "Server error" : "Serverfejl",
-    "An unknown error occurred" : "En ukendt fejl er opstået",
-    "Opening HTML drafts is not supported yet." : "Åbning af HTML-kladder understøttes endnu ikke.",
-    "No writable calendars found" : "Ingen skrivbare kalendre fundet",
-    "Error while importing the calendar event" : "Fejl ved import af kalender begivenhed",
-    "Error while downloading calendar event" : "Fejl ved hentning af kalender begivenhed",
-    "& others" : "& andre",
-    "Error while loading messages." : "Fejl under indlæsning af beskeder.",
-    "Error while refreshing messages." : "Der opstod en fejl under opdatering af besked.",
-    "Setting up your account" : "Opsætter din konto",
     "Inbox" : "Indbakke",
-    "Sent" : "Sent",
+    "Sent" : "Sendt",
     "Drafts" : "Udkast",
     "Archive" : "Arkiv",
     "Trash" : "Papirkurv",
@@ -58,23 +13,63 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "Fejl ved autodetektion. Anvend venligst manuel opsætning",
     "Creating account failed: " : "Oprettelse af konto mislykkedes:",
     "Delete permanently" : "Slet permanent",
-    "Error loading message" : "Fejl under indlæsning af besked",
-    "Settings" : "Indstillinger",
-    "Forwarding to %s" : "Videre send til %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
-    "Redirect" : "Omdiriger",
-    "The link leads to %s" : "Linket fører til %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker at besøge denne side, kan du vende tilbage til <a href=\"%s\">Mail</a>.",
-    "Continue to %s" : "Videre til %s",
-    "Delete account" : "Slet konto",
-    "Try again" : "Prøv igen",
-    "New message" : "Ny besked",
-    "Account Settings" : "Konto indstillinger",
-    "Aliases" : "Aliases",
-    "Mail address" : "Mail addresse",
-    "Display Name" : "Vist navn",
-    "Delete" : "Slet",
+    "IMAP web client" : "IMAP webklient",
+    "Auto" : "Auto",
+    "Name" : "Navn",
+    "Mail Address" : "Email addresse",
+    "Password" : "Kodeord",
+    "Manual" : "Manuel",
+    "IMAP Settings" : "IMAP opsætning",
+    "IMAP Host" : "IMAP host",
+    "IMAP Security" : "IMAP sikkerhed",
+    "None" : "Ingen",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "IMAP port",
+    "IMAP User" : "IMAP bruger",
+    "IMAP Password" : "IMAP kodeord",
+    "SMTP Settings" : "SMTP opsætnin",
+    "SMTP Host" : "SMTP host",
+    "SMTP Security" : "SMTP sikkerhed",
+    "SMTP Port" : "SMTP port",
+    "SMTP User" : "SMTP bruger",
+    "SMTP Password" : "SMTP kodeord",
+    "Connect" : "Tilslut",
+    "Add mail account" : "Tilføj mail konto",
     "Keyboard shortcuts" : "Tastaturgenveje",
+    "from" : "fra",
+    "to" : "til",
+    "+ cc/bcc" : "+ cc/bcc",
+    "cc" : "cc",
+    "bcc" : "bcc",
+    "Subject" : "Emne",
+    "Message …" : "Besked…",
+    "Saving draft …" : "Gemmer kladde…",
+    "Draft saved" : "Kladde gemt",
+    "Uploading attachments …" : "Uploader vedhæftninger",
+    "Sending …" : "Sender ...",
+    "Go back" : "Gå tilbage",
+    "Retry" : "Prøv igen",
+    "Message sent!" : "Beskeden blev sendt!",
+    "Send" : "Send",
+    "Upload attachment" : "Upload vedhæftning",
+    "Add attachment from Files" : "Vedhæft fra filer",
+    "Choose a file to add as attachment" : "Vælg en fil, der skal tilføjes som vedhæftning",
+    "Mark read" : "Marker som læst",
+    "Mark unread" : "Marker som ulæst",
+    "Delete" : "Slet",
+    "Loading messages" : "Henter beskedder",
+    "Not found" : "Ikke fundet",
+    "Import into calendar" : "Importere til kalender",
+    "Download attachment" : "Hent vedhæftning",
+    "Save to Files" : "Gem til filer",
+    "Choose a folder to store the attachment in" : "Vælg den mappe, hvor vedhæftningen skal gemmes i",
+    "Save all to Files" : "Gem alle filer",
+    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
+    "New message" : "Ny besked",
+    "Settings" : "Indstillinger",
+    "Show all folders" : "Vis all mappe",
+    "Collapse folders" : "Fold mapper sammen",
     "Speed up your Mail experience with these quick shortcuts." : "Gør brugen af Mail hurtige med disse genveje.",
     "Compose new message" : "Skriv en ny meddelelse",
     "Newer message" : "Nyere besked",
@@ -84,38 +79,18 @@ OC.L10N.register(
     "Search" : "Søg",
     "Refresh" : "Opdatér",
     "Connect your mail account" : "Forbind din mail konto",
-    "Name" : "Navn",
-    "Mail Address" : "Email addresse",
-    "Password" : "Kodeord",
-    "Manual configuration" : "Manual opsætning",
-    "IMAP Host" : "IMAP host",
-    "IMAP security" : "IMAP sikkerhed",
-    "None" : "Ingen",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "IMAP port",
-    "IMAP User" : "IMAP bruger",
-    "IMAP Password" : "IMAP kodeord",
-    "SMTP Host" : "SMTP host",
-    "SMTP security" : "SMTP sikkerhed",
-    "SMTP Port" : "SMTP port",
-    "SMTP User" : "SMTP bruger",
-    "SMTP Password" : "SMTP kodeord",
-    "Connect" : "Tilslut",
-    "from" : "fra",
-    "to" : "til",
-    "cc" : "cc",
-    "bcc" : "bcc",
-    "Subject" : "Emne",
-    "Save all to Files" : "Gem alle filer",
-    "Add mail account" : "Tilføj mail konto",
-    "No search results for" : "Ingen søge resultater for",
-    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
-    "Show images from this sender" : "Vis billeder fra denne afsender",
-    "Forward" : "Videre send",
-    "Upload attachment" : "Upload vedhæftning",
-    "Add attachment from Files" : "Vedhæft fra filer",
-    "Import into calendar" : "Importere til kalender",
-    "Download attachment" : "Hent vedhæftning",
-    "Save to Files" : "Gem til filer"
+    "{from}\n{subject}" : "{fra}\n{emne}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny besked \nfra {from}","%n nye beskeder \nfra {from}"],
+    "Nextcloud Mail" : "Nextcloud Mail",
+    "All inboxes" : "Alle indbakker",
+    "Could not load {tag}{name}{endtag}" : "Kunne ikke hente {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Der var et problem med at hente {tag}{name}{endtag}",
+    "Error loading message" : "Fejl under indlæsning af besked",
+    "Forwarding to %s" : "Videre send til %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
+    "Redirect" : "Omdiriger",
+    "The link leads to %s" : "Linket fører til %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker at besøge denne side, kan du vende tilbage til <a href=\"%s\">Mail</a>.",
+    "Continue to %s" : "Videre til %s"
 },
 "nplurals=2; plural=(n != 1);");
