@@ -2,56 +2,6 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Correo electrónico",
-    "Loading accounts" : "Cargando cuentas",
-    "Error while loading the accounts." : "Error al cargar las cuentas.",
-    "Can not load this folder." : "No se puede cargar esta carpeta.",
-    "Searching for {query}" : "Buscando {query}",
-    "Error while deleting message." : "Error al eliminar el mensaje.",
-    "Forwarded message" : "Mensaje reenviado",
-    "Choose a folder to store the attachment in" : "Escoja una carpeta para guardar el adjunto",
-    "Attachments saved to Files." : "Archivos adjuntos guardados en Archivos.",
-    "Attachment saved to Files." : "Archivo adjunto guardado en Archivos.",
-    "Error while saving attachments to Files." : "Error al guardar archivos adjuntos en Archivos.",
-    "Error while saving attachment to Files." : "Error al guardar archivo adjunto en Archivos.",
-    "Message flag could not be set." : "No se ha podido marcar el mensaje. ",
-    "Could not move message." : "No se ha podido mover el mensaje",
-    "Invalid account" : "Cuenta inválida",
-    "Invalid folder" : "Carpeta inválida",
-    "Error while creating the account: " : "Error al crear la cuenta:",
-    "Unknown error" : "Error desconocido",
-    "Error while updating the account: " : "Error al actualizar la cuenta:",
-    "All inboxes" : "Todas las bandejas de entrada",
-    "you" : "ti",
-    "Send message to {email}" : "Enviar mensaje a {email}",
-    "Could not load {tag}{name}{endtag}" : "No se ha podido cargar {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Ha habido un problema al cargar {tag}{name}{endtag}",
-    "Could not load your message" : "No se ha podido cargar tu mensaje",
-    "Could not load the desired message" : "No se ha podido cargar el mensaje deseado",
-    "Could not load the message" : "No se ha podido cargar el mensaje",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos\nde {from}"],
-    "Nextcloud Mail" : "Correo de Nextcloud",
-    "Save" : "Guardar",
-    "Saved" : "Guardado",
-    "Show all folders" : "Mostrar todas las carpetas",
-    "Collapse folders" : "Ocultar carpetas",
-    "Error while deleting account." : "Error al eliminar la cuenta.",
-    "Choose a file to add as attachment" : "Escoja un archivo para adjuntar",
-    "An error occurred while uploading {fname}" : "Ha ocurrido un error al cargar {fname}",
-    "Reply" : "Responder",
-    "Send" : "Enviar",
-    "Sending …" : "Enviando ...",
-    "Message sent!" : "¡Mensaje enviado!",
-    "Server error" : "Error en el servidor",
-    "An unknown error occurred" : "Se ha producido un error desconocido",
-    "Opening HTML drafts is not supported yet." : "La apertura de borradores HTML aun no está soportada.",
-    "No writable calendars found" : "No se han encontrado calendarios con permiso de escritura",
-    "Error while importing the calendar event" : "Error al importar el evento de calendario",
-    "Error while downloading calendar event" : "Error al descargar el evento de calendario",
-    "& others" : "y otros",
-    "Error while loading messages." : "Error al cargar los mensajes.",
-    "Error while refreshing messages." : "Error al recargar los mensajes.",
-    "Setting up your account" : "Configurando tu cuenta",
     "Inbox" : "Bandeja de entrada",
     "Sent" : "Enviados",
     "Drafts" : "Borradores",
@@ -66,25 +16,79 @@ OC.L10N.register(
     "Delete permanently" : "Eliminar permanentemente",
     "IMAP web client" : "Cliente IMAP web",
     "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Cliente de correo fácil de usar que se conecta a tu servidor de correo vía IMAP y SMTP.",
-    "Error loading message" : "Error al cargar el mensaje",
-    "Settings" : "Ajustes",
-    "Forwarding to %s" : "Reenviando a %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Haz clic aquí si no eres redirigido automáticamente en unos segundos.",
-    "Redirect" : "Redirigir",
-    "The link leads to %s" : "El enlace conduce a %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no desea visitar esa página, puede volver a <a href=\"%s\">Correo</a>.",
-    "Continue to %s" : "Continuar a %s",
-    "Delete account" : "Eliminar cuenta",
-    "Try again" : "Vuelve a intentarlo",
-    "New message" : "Nuevo mensaje",
-    "Account Settings" : "Ajustes de la cuenta",
-    "Aliases" : "Alias",
-    "Mail address" : "Dirección de correo electrónico",
-    "Display Name" : "Nombre a mostrar",
-    "Account" : "Cuenta",
-    "Toggle read" : "Marcar/desmarcar leído",
-    "Delete" : "Eliminar",
+    "Auto" : "Auto",
+    "Name" : "Nombre",
+    "Mail Address" : "Dirección de correo electrónico",
+    "Password" : "Contraseña",
+    "Manual" : "Manual",
+    "IMAP Settings" : "Configuración IMAP",
+    "IMAP Host" : "Servidor IMAP",
+    "IMAP Security" : "Seguridad IMAP",
+    "None" : "Ninguno",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "Puerto IMAP",
+    "IMAP User" : "Usuario IMAP",
+    "IMAP Password" : "Contraseña IMAP",
+    "SMTP Settings" : "Configuración SMTP",
+    "SMTP Host" : "Servidor SMTP",
+    "SMTP Security" : "Seguridad SMTP",
+    "SMTP Port" : "Puerto SMTP",
+    "SMTP User" : "Usuario SMTP",
+    "SMTP Password" : "Contraseña SMTP",
+    "Save" : "Guardar",
+    "Connect" : "Conectar",
+    "Add mail account" : "Añadir cuenta de correo",
+    "Use Gravatar and favicon avatars" : "Usar avatares de Gravatar y favicon",
     "Keyboard shortcuts" : "Atajos de teclado",
+    "from" : "de",
+    "to" : "para",
+    "+ cc/bcc" : "+ cc/cco",
+    "cc" : "cc",
+    "bcc" : "cco",
+    "Subject" : "Asunto",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Nota: el correo viene de una dirección noreply (no responder), por lo que\ttu respuesta probablemente no será leída.",
+    "Message …" : "Mensaje…",
+    "Saving draft …" : "Guardando borrador…",
+    "Draft saved" : "Borrador guardado",
+    "Uploading attachments …" : "Subiendo adjuntos…",
+    "Sending …" : "Enviando ...",
+    "Error sending your message" : "Error al enviar tu mensaje",
+    "Go back" : "Volver",
+    "Retry" : "Volver a intentar",
+    "Message sent!" : "¡Mensaje enviado!",
+    "Reply sent!" : "Respuesta enviada.",
+    "Write another message" : "Escribir otro mensaje",
+    "Send" : "Enviar",
+    "Uploading {percent}% …" : "Subiendo {percent}% …",
+    "Upload attachment" : "Subir adjunto",
+    "Add attachment from Files" : "Añadir adjunto desde Archivos",
+    "Choose a file to add as attachment" : "Escoja un archivo para adjuntar",
+    "No messages in this folder" : "No hay mensajes en esta carpeta",
+    "Draft: " : "Borrador:",
+    "Mark read" : "Marcar como leído",
+    "Mark unread" : "Marcar como no leído",
+    "Delete" : "Eliminar",
+    "Report this bug" : "Informar de este error",
+    "Loading messages" : "Cargando mensajes",
+    "Not found" : "No encontrado",
+    "Could not load your message" : "No se ha podido cargar tu mensaje",
+    "Import into calendar" : "Importar al calendario",
+    "Download attachment" : "Descargar adjunto",
+    "Save to Files" : "Guardar en Archivos",
+    "Choose a folder to store the attachment in" : "Escoja una carpeta para guardar el adjunto",
+    "Save all to Files" : "Guardar todo en Archivos",
+    "Choose a folder to store the attachments in" : "Escoge una carpeta donde guardar los adjuntos",
+    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad.",
+    "Show images from this\tsender" : "Mostrar imágenes de este\tremitente",
+    "New message" : "Nuevo mensaje",
+    "Settings" : "Ajustes",
+    "Edit" : "Editar",
+    "Show all folders" : "Mostrar todas las carpetas",
+    "Collapse folders" : "Ocultar carpetas",
+    "Could not load your draft" : "No se ha podido cargar el borrador",
+    "No message selected" : "Ningún mensaje seleccionado",
+    "Account Settings" : "Ajustes de la cuenta",
     "Speed up your Mail experience with these quick shortcuts." : "Acelera tu experiencia de Correo con estos rápidos atajos de teclado.",
     "Compose new message" : "Crear nuevo mensaje",
     "Newer message" : "Mensaje más moderno",
@@ -94,41 +98,20 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Refresh" : "Recargar",
     "Connect your mail account" : "Conecte su cuenta de correo electrónico",
-    "Name" : "Nombre",
-    "Mail Address" : "Dirección de correo electrónico",
-    "Password" : "Contraseña",
-    "Manual configuration" : "Configuración manual",
-    "IMAP Host" : "Servidor IMAP",
-    "IMAP security" : "Seguridad IMAP",
-    "None" : "Ninguno",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "Puerto IMAP",
-    "IMAP User" : "Usuario IMAP",
-    "IMAP Password" : "Contraseña IMAP",
-    "SMTP Host" : "Servidor SMTP",
-    "SMTP security" : "Seguridad SMTP",
-    "SMTP Port" : "Puerto SMTP",
-    "SMTP User" : "Usuario SMTP",
-    "SMTP Password" : "Contraseña SMTP",
-    "Connect" : "Conectar",
-    "from" : "de",
-    "to" : "para",
-    "cc" : "cc",
-    "bcc" : "cco",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Nota: el correo viene de una dirección noreply (no responder), por lo que probablemente no será leído.",
-    "Subject" : "Asunto",
-    "Save all to Files" : "Guardar todo en Archivos",
-    "Add mail account" : "Añadir cuenta de correo",
-    "Use Gravatar and favicon avatars" : "Usar avatares de Gravatar y favicon",
-    "No search results for" : "Ningún resultado para la búsqueda de",
-    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad.",
-    "Show images from this sender" : "Mostrar imágenes de este remitente",
-    "Forward" : "Reenviar",
-    "No messages in this folder" : "No hay mensajes en esta carpeta",
-    "Upload attachment" : "Subir adjunto",
-    "Add attachment from Files" : "Añadir adjunto desde Archivos",
-    "Import into calendar" : "Importar al calendario",
-    "Download attachment" : "Descargar adjunto",
-    "Save to Files" : "Guardar en Archivos"
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos\nde {from}"],
+    "Nextcloud Mail" : "Correo de Nextcloud",
+    "All inboxes" : "Todas las bandejas de entrada",
+    "Could not load {tag}{name}{endtag}" : "No se ha podido cargar {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Ha habido un problema al cargar {tag}{name}{endtag}",
+    "Could not load the desired message" : "No se ha podido cargar el mensaje deseado",
+    "Could not load the message" : "No se ha podido cargar el mensaje",
+    "Error loading message" : "Error al cargar el mensaje",
+    "Forwarding to %s" : "Reenviando a %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Haz clic aquí si no eres redirigido automáticamente en unos segundos.",
+    "Redirect" : "Redirigir",
+    "The link leads to %s" : "El enlace conduce a %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no desea visitar esa página, puede volver a <a href=\"%s\">Correo</a>.",
+    "Continue to %s" : "Continuar a %s"
 },
 "nplurals=2; plural=(n != 1);");
