@@ -2,56 +2,6 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Mail",
-    "Loading accounts" : "Chargement des comptes",
-    "Error while loading the accounts." : "Erreur lors du chargement des comptes.",
-    "Can not load this folder." : "Impossible de charger ce dossier.",
-    "Searching for {query}" : "Recherche pour {query}",
-    "Error while deleting message." : "Erreur lors de la suppression du message.",
-    "Forwarded message" : "Message transféré",
-    "Choose a folder to store the attachment in" : "Choisissez le dossier dans lequel enregistrer la pièce jointe",
-    "Attachments saved to Files." : "Pièces jointes enregistrées dans les Fichiers.",
-    "Attachment saved to Files." : "Pièce jointe enregistrée dans les Fichiers.",
-    "Error while saving attachments to Files." : "Erreur lors de l'enregistrement des pièces jointes dans les Fichiers.",
-    "Error while saving attachment to Files." : "Erreur lors de l'enregistrement de la pièce jointe dans les Fichiers.",
-    "Message flag could not be set." : "Le drapeau n'a pas été ajouté sur le message.",
-    "Could not move message." : "Impossible de déplacer le message.",
-    "Invalid account" : "Compte invalide",
-    "Invalid folder" : "Dossier invalide",
-    "Error while creating the account: " : "Erreur lors de la création du compte:",
-    "Unknown error" : "Erreur inconnue",
-    "Error while updating the account: " : "Erreur lors de la mise à jour du compte :",
-    "All inboxes" : "Toutes les boîtes",
-    "you" : "vous",
-    "Send message to {email}" : "Envoyer un mail à {email}",
-    "Could not load {tag}{name}{endtag}" : "Impossible de charger {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Il y a eu un problème de chargement {tag}{name}{endtag}",
-    "Could not load your message" : "Impossible de charger votre message",
-    "Could not load the desired message" : "Impossible de charger le message souhaité",
-    "Could not load the message" : "Impossible de charger le message",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nouveau message\nde {from}","%n nouveaux messages\nde {from}"],
-    "Nextcloud Mail" : "Nextcloud Mail",
-    "Save" : "Sauvegarder",
-    "Saved" : "Sauvegardé",
-    "Show all folders" : "Montrer tous les dossiers",
-    "Collapse folders" : "Replier les dossiers",
-    "Error while deleting account." : "Erreur lors de la suppression du compte.",
-    "Choose a file to add as attachment" : "Choisissez un fichier à joindre au message",
-    "An error occurred while uploading {fname}" : "Une erreur est survenue lors du téléversement de la pièce-jointe {fname}",
-    "Reply" : "Répondre",
-    "Send" : "Envoyer",
-    "Sending …" : "Envoi…",
-    "Message sent!" : "Message envoyé !",
-    "Server error" : "Erreur du serveur",
-    "An unknown error occurred" : "Une erreur inconnue est survenue",
-    "Opening HTML drafts is not supported yet." : "L'ouverture de brouillons au format HTML n'est pas prise en charge pour le moment.",
-    "No writable calendars found" : "Aucun calendrier modifiable n'a été trouvé",
-    "Error while importing the calendar event" : "Erreur pendant l'importation de l'évènement du calendrier",
-    "Error while downloading calendar event" : "Erreur pendant le téléchargement de l'évènement du calendrier",
-    "& others" : "et d'autres",
-    "Error while loading messages." : "Erreur lors du chargement des messages.",
-    "Error while refreshing messages." : "Erreur lors de l'actualisation des messages.",
-    "Setting up your account" : "Paramétrage de votre compte",
     "Inbox" : "Boîte de réception",
     "Sent" : "Envoyés",
     "Drafts" : "Brouillons",
@@ -66,25 +16,82 @@ OC.L10N.register(
     "Delete permanently" : "Supprimer définitivement",
     "IMAP web client" : "Client web IMAP",
     "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Client de messagerie facile à utiliser qui se connecte à votre serveur de messagerie via IMAP et SMTP.",
-    "Error loading message" : "Erreur lors du chargement du message",
-    "Settings" : "Paramètres",
-    "Forwarding to %s" : "Faire suivre à %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Cliquer ici si vous n'êtes pas automatiquement redirigé dans les prochaines secondes.",
-    "Redirect" : "Redirection",
-    "The link leads to %s" : "Le lien dirige vers %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si vous ne désirez pas visiter cette page, vous pouvez retourner aux <a href=\"%s\">Mails</a>.",
-    "Continue to %s" : "Continuer vers %s",
-    "Delete account" : "Supprimer le compte",
-    "Try again" : "Réessayez",
-    "New message" : "Nouveau message",
-    "Account Settings" : "Paramètres du compte",
-    "Aliases" : "Alias",
-    "Mail address" : "Adresse mail",
-    "Display Name" : "Nom affiché",
-    "Account" : "Compte",
-    "Toggle read" : "Basculer en lecture",
-    "Delete" : "Supprimer",
+    "Auto" : "Auto",
+    "Name" : "Nom",
+    "Mail Address" : "Adresse mail",
+    "Password" : "Mot de passe",
+    "Manual" : "Manuel",
+    "IMAP Settings" : "Paramètres IMAP",
+    "IMAP Host" : "Hôte IMAP",
+    "IMAP Security" : "Sécurité IMAP",
+    "None" : "Aucun",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "Port IMAP",
+    "IMAP User" : "Utilisateur IMAP",
+    "IMAP Password" : "Mot de passe IMAP",
+    "SMTP Settings" : "Paramètres SMTP",
+    "SMTP Host" : "Hôte SMTP",
+    "SMTP Security" : "Sécurité SMTP",
+    "SMTP Port" : "Port SMTP",
+    "SMTP User" : "Utilisateur SMTP",
+    "SMTP Password" : "Mot de passe SMTP",
+    "Save" : "Enregistrer",
+    "Connect" : "Connecter",
+    "Add mail account" : "Ajouter un compte mail",
+    "Use Gravatar and favicon avatars" : "Utiliser Gravatar et des avatars de favicon",
     "Keyboard shortcuts" : "Raccourcis clavier",
+    "from" : "de",
+    "to" : "vers",
+    "+ cc/bcc" : "+ cc/bcc",
+    "cc" : "cc",
+    "bcc" : "bcc",
+    "Subject" : "Sujet",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Notez que le mail provient d'une adresse noreply donc\tvotre réponse ne sera sans doute pas lu.",
+    "Message …" : "Message …",
+    "Saving draft …" : "Sauvegarde du brouillon en cours …",
+    "Draft saved" : "Brouillon sauvegardé",
+    "Uploading attachments …" : "Téléversement des pièces jointes en cours …",
+    "Sending …" : "Envoi…",
+    "Error sending your message" : "Erreur lors de l'envoi de votre message",
+    "Go back" : "Revenir en arrière",
+    "Retry" : "Réessayer",
+    "Message sent!" : "Message envoyé !",
+    "Reply sent!" : "Réponse envoyé !",
+    "Write another message" : "Écrire un autre message",
+    "Send" : "Envoyer",
+    "Uploading {percent}% …" : "Envoi {percent}% …",
+    "Upload attachment" : "Téléverser les pièces jointes",
+    "Add attachment from Files" : "Ajouter des pièces jointes depuis Fichiers",
+    "Choose a file to add as attachment" : "Choisissez un fichier à joindre au message",
+    "No messages in this folder" : "Aucun message dans ce dossier",
+    "Draft: " : "Brouillon :",
+    "Mark read" : "Marquer comme lu",
+    "Mark unread" : "Marquer comme non-lu",
+    "Delete" : "Supprimer",
+    "Report this bug" : "Signaler ce bogue",
+    "Loading messages" : "Chargement des messages",
+    "Not found" : "Non trouvé",
+    "Could not load your message" : "Impossible de charger votre message",
+    "Import into calendar" : "Importer dans le calendrier",
+    "Download attachment" : "Télécharger les pièces jointes",
+    "Save to Files" : "Enregistrer dans Fichiers",
+    "Choose a folder to store the attachment in" : "Choisissez le dossier dans lequel enregistrer la pièce jointe",
+    "Save all to Files" : "Enregistrer tout dans les Fichiers",
+    "Choose a folder to store the attachments in" : "Choisissez un dossier dans lequel enregistrer les pièces jointes",
+    "The images have been blocked to protect your privacy." : "Les images ont été bloquées pour protéger votre vie privée.",
+    "Show images from this\tsender" : "Voir les images de cet\texpéditeur",
+    "New message" : "Nouveau message",
+    "Settings" : "Paramètres",
+    "Edit" : "Modifier",
+    "Show all folders" : "Montrer tous les dossiers",
+    "Collapse folders" : "Replier les dossiers",
+    "Could not load your draft" : "Impossible de charger votre brouillon",
+    "No message selected" : "Aucun message sélectionné",
+    "Signature" : "Signature",
+    "A signature will be added to the text of new and response messages." : "Une signature sera ajoutée sur les nouveaux messages et les réponses.",
+    "Account Settings" : "Paramètres du compte",
+    "Mail server" : "Serveur de messagerie",
     "Speed up your Mail experience with these quick shortcuts." : "Accélérez votre expérience Mail avec ces raccourcis rapides.",
     "Compose new message" : "Rédigez un nouveau message",
     "Newer message" : "Message plus récent",
@@ -94,41 +101,20 @@ OC.L10N.register(
     "Search" : "Rechercher",
     "Refresh" : "Rafraîchir",
     "Connect your mail account" : "Connecter votre compte mail",
-    "Name" : "Nom",
-    "Mail Address" : "Adresse mail",
-    "Password" : "Mot de passe",
-    "Manual configuration" : "Configuration manuelle",
-    "IMAP Host" : "Hôte IMAP",
-    "IMAP security" : "Sécurité IMAP",
-    "None" : "Aucun",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "Port IMAP",
-    "IMAP User" : "Utilisateur IMAP",
-    "IMAP Password" : "Mot de passe IMAP",
-    "SMTP Host" : "Hôte SMTP",
-    "SMTP security" : "Sécurité SMTP",
-    "SMTP Port" : "Port SMTP",
-    "SMTP User" : "Utilisateur SMTP",
-    "SMTP Password" : "Mot de passe SMTP",
-    "Connect" : "Connecter",
-    "from" : "de",
-    "to" : "vers",
-    "cc" : "cc",
-    "bcc" : "bcc",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Notez que le mail provient d'une adresse noreply donc votre réponse ne sera sans doute pas lu.",
-    "Subject" : "Sujet",
-    "Save all to Files" : "Enregistrer tout dans les Fichiers",
-    "Add mail account" : "Ajouter un compte mail",
-    "Use Gravatar and favicon avatars" : "Utiliser Gravatar et des avatars de favicon",
-    "No search results for" : "Aucun résultats pour",
-    "The images have been blocked to protect your privacy." : "Les images ont été bloquées pour protéger votre vie privée.",
-    "Show images from this sender" : "Voir les images de cet expéditeur",
-    "Forward" : "Faire suivre",
-    "No messages in this folder" : "Aucun message dans ce dossier",
-    "Upload attachment" : "Téléverser les pièces jointes",
-    "Add attachment from Files" : "Ajouter des pièces jointes depuis Fichiers",
-    "Import into calendar" : "Importer dans le calendrier",
-    "Download attachment" : "Télécharger les pièces jointes",
-    "Save to Files" : "Enregistrer dans Fichiers"
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nouveau message\nde {from}","%n nouveaux messages\nde {from}"],
+    "Nextcloud Mail" : "Nextcloud Mail",
+    "All inboxes" : "Toutes les boîtes",
+    "Could not load {tag}{name}{endtag}" : "Impossible de charger {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Il y a eu un problème de chargement {tag}{name}{endtag}",
+    "Could not load the desired message" : "Impossible de charger le message souhaité",
+    "Could not load the message" : "Impossible de charger le message",
+    "Error loading message" : "Erreur lors du chargement du message",
+    "Forwarding to %s" : "Faire suivre à %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Cliquer ici si vous n'êtes pas automatiquement redirigé dans les prochaines secondes.",
+    "Redirect" : "Redirection",
+    "The link leads to %s" : "Le lien dirige vers %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si vous ne désirez pas visiter cette page, vous pouvez retourner aux <a href=\"%s\">Mails</a>.",
+    "Continue to %s" : "Continuer vers %s"
 },
 "nplurals=2; plural=(n > 1);");
