@@ -2,56 +2,6 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Levelezés",
-    "Loading accounts" : "Fiókok betöltése",
-    "Error while loading the accounts." : "Hiba történt a fiókok betöltése közben.",
-    "Can not load this folder." : "Ezt a mappát nem lehet betölteni.",
-    "Searching for {query}" : "Keresés: {query}",
-    "Error while deleting message." : "Hiba történt az üzenet törlése közben.",
-    "Forwarded message" : "Továbbított üzenet",
-    "Choose a folder to store the attachment in" : "Válasszon egy mappát a mellékletek tárolásához:",
-    "Attachments saved to Files." : "Mellékletek mentve a Fájlokba.",
-    "Attachment saved to Files." : "Melléklet mentve a Fájlokba.",
-    "Error while saving attachments to Files." : "Hiba történt a mellékletek Fájlokba mentése közben.",
-    "Error while saving attachment to Files." : "Hiba történt a melléklet Fájlokba mentése közben.",
-    "Message flag could not be set." : "Üzenet zászló nem állítható be.",
-    "Could not move message." : "Nem lehet áthelyezni az üzenetet",
-    "Invalid account" : "Érvénytelen fiók",
-    "Invalid folder" : "Érvénytelen mappa",
-    "Error while creating the account: " : "Hiba történt a fiók létrehozásakor:",
-    "Unknown error" : "Ismeretlen hiba",
-    "Error while updating the account: " : "Hiba történt a fiók frissítése közben:",
-    "All inboxes" : "Minden bejövő",
-    "you" : "te",
-    "Send message to {email}" : "Üzenet küldés ide: {email}",
-    "Could not load {tag}{name}{endtag}" : "Nem tölthető be: {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Probléma volt a betöltéssel: {tag}{name}{endtag}",
-    "Could not load your message" : "Nem lehet betölteni az üzenetedet",
-    "Could not load the desired message" : "Nem lehet betölteni a kért üzenetet",
-    "Could not load the message" : "Nem lehet betölteni az üzenetet",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n új üzenet \nfeladó: {from}","%n új üzenet \nfeladó: {from}"],
-    "Nextcloud Mail" : "Nextcloud Mail",
-    "Save" : "Mentés",
-    "Saved" : "Elmentve",
-    "Show all folders" : "Minden mappa megjelenítése",
-    "Collapse folders" : "Mappák összecsukása",
-    "Error while deleting account." : "Hiba történt a fiók törlése közben.",
-    "Choose a file to add as attachment" : "Csatolandó fájl kiválasztása",
-    "An error occurred while uploading {fname}" : "Hiba a(z) {fname} feltöltése közben",
-    "Reply" : "Válasz",
-    "Send" : "Küldés",
-    "Sending …" : "Küldés...",
-    "Message sent!" : "Üzenet elküldve!",
-    "Server error" : "Szerver hiba",
-    "An unknown error occurred" : "Ismeretlen hiba történt",
-    "Opening HTML drafts is not supported yet." : "A HTML vázlatok megnyitása még nem támogatott.",
-    "No writable calendars found" : "Nem található írható naptár",
-    "Error while importing the calendar event" : "Hiba a naptár esemény importálása közben",
-    "Error while downloading calendar event" : "Hiba a naptár esemény letöltése közben",
-    "& others" : "és mások",
-    "Error while loading messages." : "Hiba történt az üzenetek betöltése közben.",
-    "Error while refreshing messages." : "Hiba az üzenetek frissítése közben.",
-    "Setting up your account" : "Fiókod beállítása",
     "Inbox" : "Bejövő",
     "Sent" : "Elküldött",
     "Drafts" : "Vázlatok",
@@ -64,24 +14,60 @@ OC.L10N.register(
     "Updating account failed: " : "Fiók frissítése sikertelen:",
     "Creating account failed: " : "Fiók létrehozása sikertelen: ",
     "Delete permanently" : "Végleges törlés",
-    "Error loading message" : "Hiba történt az üzenet betöltése közben",
-    "Settings" : "Beállítások",
-    "Forwarding to %s" : "Továbbítás ide: %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Kattints ide, ha a következő néhány másodpercben lennél automatikusan átirányítva.",
-    "Redirect" : "Átirányítás",
-    "The link leads to %s" : "A hivatkozás ide mutat: %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarod megnyitni azt az oldalt, akkor térj vissza a <a href=\"%s\">Levelekhez</a>",
-    "Continue to %s" : "Folytatás ide: %s",
-    "Delete account" : "Fiók törlése",
-    "Try again" : "Próbáld újra",
-    "New message" : "Új üzenet",
-    "Account Settings" : "Fiók beállítások",
-    "Aliases" : "Álnevek",
-    "Mail address" : "E-mail cím",
-    "Display Name" : "Megjelenített név",
-    "Account" : "Fiók",
-    "Delete" : "Törlés",
+    "IMAP web client" : "IMAP web kliens",
+    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Könnyen használható levelező kliens mely a levelező szerveredhez csatlakozik IMAP és SMTP protokolon.",
+    "Name" : "Név",
+    "Mail Address" : "E-mail cím",
+    "Password" : "Jelszó",
+    "Manual" : "Manuális",
+    "IMAP Host" : "IMAP kiszolgáló",
+    "IMAP Security" : "IMAP Biztonság",
+    "None" : "Semmi",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "IMAP port",
+    "IMAP User" : "IMAP felhasználó",
+    "IMAP Password" : "IMAP jelszó",
+    "SMTP Settings" : "SMTP Beállítások",
+    "SMTP Host" : "SMTP kiszolgáló",
+    "SMTP Port" : "SMTP port",
+    "SMTP User" : "SMTP felhasználó",
+    "SMTP Password" : "SMTP jelszó",
+    "Save" : "Mentés",
+    "Connect" : "Csatlakozás",
+    "Add mail account" : "E-mail fiók hozzáadás",
+    "Use Gravatar and favicon avatars" : "Gravatar és favicon avatarok használata",
     "Keyboard shortcuts" : "Gyorsbillentyűk",
+    "from" : "feladó",
+    "to" : "címzett",
+    "+ cc/bcc" : "+ cc/bcc",
+    "cc" : "másolat",
+    "bcc" : "titkos másolat",
+    "Subject" : "Tárgy",
+    "Message …" : "Üzenet ...",
+    "Sending …" : "Küldés...",
+    "Error sending your message" : "Hiba az üzeneted elküldésekor",
+    "Go back" : "Visszalép",
+    "Message sent!" : "Üzenet elküldve!",
+    "Reply sent!" : "Válasz elküldve!",
+    "Send" : "Küldés",
+    "Upload attachment" : "Csatolmány feltöltése",
+    "Add attachment from Files" : "Csatolmány hozzáadása a Fájlok közül",
+    "Choose a file to add as attachment" : "Csatolandó fájl kiválasztása",
+    "No messages in this folder" : "Nincs üzenet a mappában!",
+    "Delete" : "Törlés",
+    "Loading messages" : "Üzenetek betöltése",
+    "Could not load your message" : "Nem lehet betölteni az üzenetedet",
+    "Import into calendar" : "Betöltés a naptárba",
+    "Download attachment" : "Melléklet letöltése",
+    "Save to Files" : "Metés a Fájlokba",
+    "Choose a folder to store the attachment in" : "Válasszon egy mappát a mellékletek tárolásához:",
+    "Save all to Files" : "Minden mentése a Fájlokba",
+    "The images have been blocked to protect your privacy." : "A személyes adataid védelme érdekében a képeket letiltottuk.",
+    "New message" : "Új üzenet",
+    "Settings" : "Beállítások",
+    "Show all folders" : "Minden mappa megjelenítése",
+    "Collapse folders" : "Mappák összecsukása",
+    "Account Settings" : "Fiók beállítások",
     "Speed up your Mail experience with these quick shortcuts." : "Gyorsítsd fel a levelezési élményedet ezekkel a rövidítésekkel.",
     "Compose new message" : "Új üzenet írása",
     "Newer message" : "Újabb üzenet",
@@ -91,41 +77,20 @@ OC.L10N.register(
     "Search" : "Keresés",
     "Refresh" : "Frissítés",
     "Connect your mail account" : "Kapcsolódás az e-mail fiókodhoz",
-    "Name" : "Név",
-    "Mail Address" : "E-mail cím",
-    "Password" : "Jelszó",
-    "Manual configuration" : "Kézi beállítások",
-    "IMAP Host" : "IMAP kiszolgáló",
-    "IMAP security" : "IMAP biztonság",
-    "None" : "Semmi",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "IMAP port",
-    "IMAP User" : "IMAP felhasználó",
-    "IMAP Password" : "IMAP jelszó",
-    "SMTP Host" : "SMTP kiszolgáló",
-    "SMTP security" : "SMTP biztonság",
-    "SMTP Port" : "SMTP port",
-    "SMTP User" : "SMTP felhasználó",
-    "SMTP Password" : "SMTP jelszó",
-    "Connect" : "Csatlakozás",
-    "from" : "feladó",
-    "to" : "címzett",
-    "cc" : "másolat",
-    "bcc" : "titkos másolat",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Vedd figyelembe, hogy egy \"ne válaszolj\" címről jött a levél, így válaszodat valószínűleg nem fogják elolvasni.",
-    "Subject" : "Tárgy",
-    "Save all to Files" : "Minden mentése a Fájlokba",
-    "Add mail account" : "E-mail fiók hozzáadás",
-    "Use Gravatar and favicon avatars" : "Gravatar és favicon avatarok használata",
-    "No search results for" : "Ehhez nincsenek keresési eredmények",
-    "The images have been blocked to protect your privacy." : "A személyes adataid védelme érdekében a képeket letiltottuk.",
-    "Show images from this sender" : "Képek megjelenítése ettől a feladótól",
-    "Forward" : "Továbbítás",
-    "No messages in this folder" : "Nincs üzenet a mappában!",
-    "Upload attachment" : "Csatolmány feltöltése",
-    "Add attachment from Files" : "Csatolmány hozzáadása a Fájlok közül",
-    "Import into calendar" : "Betöltés a naptárba",
-    "Download attachment" : "Melléklet letöltése",
-    "Save to Files" : "Metés a Fájlokba"
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n új üzenet \nfeladó: {from}","%n új üzenet \nfeladó: {from}"],
+    "Nextcloud Mail" : "Nextcloud Mail",
+    "All inboxes" : "Minden bejövő",
+    "Could not load {tag}{name}{endtag}" : "Nem tölthető be: {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Probléma volt a betöltéssel: {tag}{name}{endtag}",
+    "Could not load the desired message" : "Nem lehet betölteni a kért üzenetet",
+    "Could not load the message" : "Nem lehet betölteni az üzenetet",
+    "Error loading message" : "Hiba történt az üzenet betöltése közben",
+    "Forwarding to %s" : "Továbbítás ide: %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Kattints ide, ha a következő néhány másodpercben lennél automatikusan átirányítva.",
+    "Redirect" : "Átirányítás",
+    "The link leads to %s" : "A hivatkozás ide mutat: %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarod megnyitni azt az oldalt, akkor térj vissza a <a href=\"%s\">Levelekhez</a>",
+    "Continue to %s" : "Folytatás ide: %s"
 },
 "nplurals=2; plural=(n != 1);");
