@@ -2,56 +2,6 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Posta",
-    "Loading accounts" : "Caricamento account",
-    "Error while loading the accounts." : "Errore durante il caricamento degli account.",
-    "Can not load this folder." : "Impossibile caricare questa cartella.",
-    "Searching for {query}" : "Ricerca di {query}",
-    "Error while deleting message." : "Errore durante l'eliminazione del messaggio.",
-    "Forwarded message" : "Messaggio inoltrato",
-    "Choose a folder to store the attachment in" : "Scegli una cartella dove salvare l'allegato",
-    "Attachments saved to Files." : "Allegati salvati in File.",
-    "Attachment saved to Files." : "Allegato salvato in File.",
-    "Error while saving attachments to Files." : "Errore durante il salvataggio degli allegati in File.",
-    "Error while saving attachment to Files." : "Errore durante il salvataggio dell'allegato in File.",
-    "Message flag could not be set." : "Il contrassegno del messaggio non può essere impostato.",
-    "Could not move message." : "Impossibile spostare il messaggio.",
-    "Invalid account" : "Account non valido",
-    "Invalid folder" : "Cartella non valida",
-    "Error while creating the account: " : "Errore durante la creazione dell'account:",
-    "Unknown error" : "Errore sconosciuto",
-    "Error while updating the account: " : "Errore durante l'aggiornamento dell'account:",
-    "All inboxes" : "Tutte le caselle di posta",
-    "you" : "tu",
-    "Send message to {email}" : "Invia messaggio a {email}",
-    "Could not load {tag}{name}{endtag}" : "Impossibile caricare {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Si è verificato un programma durante il caricamento di {tag}{name}{endtag}",
-    "Could not load your message" : "Impossibile caricare il tuo messaggio",
-    "Could not load the desired message" : "Impossibile caricare messaggio desiderato",
-    "Could not load the message" : "Impossibile caricare il messaggio",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nuovo messaggio \nda {from}","%n nuovi messaggi \nda {from}"],
-    "Nextcloud Mail" : "Nextcloud Mail",
-    "Save" : "Salva",
-    "Saved" : "Salvato",
-    "Show all folders" : "Mostra tutte le cartelle",
-    "Collapse folders" : "Contrai le cartelle",
-    "Error while deleting account." : "Errore durante l'eliminazione dell'account.",
-    "Choose a file to add as attachment" : "Scegli un file da aggiungere come allegato",
-    "An error occurred while uploading {fname}" : "Si è verificato un errore durante il caricamento di {fname}",
-    "Reply" : "Rispondi",
-    "Send" : "Invia",
-    "Sending …" : "Invio in corso...",
-    "Message sent!" : "Messaggio inviato!",
-    "Server error" : "Errore del server",
-    "An unknown error occurred" : "Si è verificato un errore sconosciuto",
-    "Opening HTML drafts is not supported yet." : "L'apertura delle bozze HTML non è ancora supportata.",
-    "No writable calendars found" : "Nessun calendario scrivibile trovato",
-    "Error while importing the calendar event" : "Errore durante l'importazione dell'evento di calendario",
-    "Error while downloading calendar event" : "Errore durante lo scaricamento dell'evento di calendario",
-    "& others" : "e altri",
-    "Error while loading messages." : "Errore durante il caricamento dei messaggi.",
-    "Error while refreshing messages." : "Errore durante l'aggiornamento dei messaggi.",
-    "Setting up your account" : "Configurazione del tuo account",
     "Inbox" : "Posta in arrivo",
     "Sent" : "Posta inviata",
     "Drafts" : "Bozze",
@@ -66,25 +16,83 @@ OC.L10N.register(
     "Delete permanently" : "Elimina definitivamente",
     "IMAP web client" : "Client web IMAP",
     "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Client di posta elettronica di facile utilizzo che ti collega al tuo server di posta tramite IMAP e SMTP.",
-    "Error loading message" : "Errore durante il caricamento del messaggio",
-    "Settings" : "Impostazioni",
-    "Forwarding to %s" : "Inoltro a %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Fai clic qui se non viene rediretto automaticamente entro pochi secondi.",
-    "Redirect" : "Redirigi",
-    "The link leads to %s" : "Il collegamento conduce a %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se non vuoi visitare tale pagina, puoi tornare all'<a href=\"%s\">applicazione di posta</a>.",
-    "Continue to %s" : "Continua su %s",
-    "Delete account" : "Elimina account",
-    "Try again" : "Riprova",
-    "New message" : "Nuovo messaggio",
-    "Account Settings" : "Impostazioni account",
-    "Aliases" : "Alias",
-    "Mail address" : "Indirizzo di posta",
-    "Display Name" : "Nome visualizzato",
-    "Account" : "Account",
-    "Toggle read" : "Commuta letto",
-    "Delete" : "Elimina",
+    "Auto" : "Automatico",
+    "Name" : "Nome",
+    "Mail Address" : "Indirizzo di posta",
+    "Password" : "Password",
+    "Manual" : "Manuale",
+    "IMAP Settings" : "Impostazioni IMAP",
+    "IMAP Host" : "Host IMAP",
+    "IMAP Security" : "Sicurezza IMAP",
+    "None" : "Nessuna",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "Porta IMAP",
+    "IMAP User" : "Utente IMAP",
+    "IMAP Password" : "Password IMAP",
+    "SMTP Settings" : "Impostazioni SMTP",
+    "SMTP Host" : "Host SMTP",
+    "SMTP Security" : "Sicurezza SMTP",
+    "SMTP Port" : "Porta SMTP",
+    "SMTP User" : "Utente SMTP",
+    "SMTP Password" : "Password SMTP",
+    "Save" : "Salva",
+    "Connect" : "Connetti",
+    "Add mail account" : "Aggiungi account di posta",
+    "Use Gravatar and favicon avatars" : "Utilizza Gravatar e avatar favicon",
     "Keyboard shortcuts" : "Scorciatoie da tastiera",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Stai cercando un modo per cifrare le tue email? Installa l'estensione per browser Mailvelope!",
+    "from" : "da",
+    "to" : "a",
+    "+ cc/bcc" : "+ cc/ccn",
+    "cc" : "cc",
+    "bcc" : "ccn",
+    "Subject" : "Oggetto",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Nota che l'email è arrivata da un indirizzo noreply, perciò\tla tua risposta probabilmente non sarà letta.",
+    "Message …" : "Messaggio…",
+    "Saving draft …" : "Salvataggio bozza…",
+    "Draft saved" : "Bozza salvata",
+    "Uploading attachments …" : "Caricamento allegati…",
+    "Sending …" : "Invio in corso...",
+    "Error sending your message" : "Errore di invio del messaggio",
+    "Go back" : "Indietro",
+    "Retry" : "Riprova",
+    "Message sent!" : "Messaggio inviato!",
+    "Reply sent!" : "Risposta inviata!",
+    "Write another message" : "Scrivi un altro messaggio",
+    "Send" : "Invia",
+    "Uploading {percent}% …" : "Caricamento {percent}% …",
+    "Upload attachment" : "Carica allegato",
+    "Add attachment from Files" : "Aggiungi allegato da File",
+    "Choose a file to add as attachment" : "Scegli un file da aggiungere come allegato",
+    "No messages in this folder" : "Nessun messaggio in questa cartella",
+    "Draft: " : "Bozza:",
+    "Mark read" : "Marca come letto",
+    "Mark unread" : "Marca come non letto",
+    "Delete" : "Elimina",
+    "Report this bug" : "Segnala questo bug",
+    "Loading messages" : "Caricamento messaggi",
+    "Not found" : "Non trovato",
+    "Could not load your message" : "Impossibile caricare il tuo messaggio",
+    "Import into calendar" : "Importa nel calendario",
+    "Download attachment" : "Scarica allegato",
+    "Save to Files" : "Salva in File",
+    "Choose a folder to store the attachment in" : "Scegli una cartella dove salvare l'allegato",
+    "Save all to Files" : "Salva tutto in File",
+    "Choose a folder to store the attachments in" : "Scegli una cartella in cui salvare gli allegati",
+    "The images have been blocked to protect your privacy." : "Le immagini sono state bloccate per proteggere la tua riservatezza.",
+    "Show images from this\tsender" : "Mostra immagini da questo\tmittente",
+    "New message" : "Nuovo messaggio",
+    "Settings" : "Impostazioni",
+    "Edit" : "Modifica",
+    "Show all folders" : "Mostra tutte le cartelle",
+    "Collapse folders" : "Contrai le cartelle",
+    "Could not load your draft" : "Impossibile caricare la tua bozza",
+    "No message selected" : "Nessun messaggio selezionato",
+    "Signature" : "Firma",
+    "A signature will be added to the text of new and response messages." : "Una firma sarà aggiunta al testo dei nuovi messaggi e delle risposte.",
+    "Account Settings" : "Impostazioni account",
+    "Mail server" : "Server di posta",
     "Speed up your Mail experience with these quick shortcuts." : "Velocizza la tua esperienza di posta elettronica con queste scorciatoie.",
     "Compose new message" : "Componi nuovo messaggio",
     "Newer message" : "Messaggio più recente",
@@ -94,41 +102,20 @@ OC.L10N.register(
     "Search" : "Cerca",
     "Refresh" : "Aggiorna",
     "Connect your mail account" : "Connetti il tuo account di posta",
-    "Name" : "Nome",
-    "Mail Address" : "Indirizzo di posta",
-    "Password" : "Password",
-    "Manual configuration" : "Configurazione manuale",
-    "IMAP Host" : "Host IMAP",
-    "IMAP security" : "Sicurezza IMAP",
-    "None" : "Nessuna",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "Porta IMAP",
-    "IMAP User" : "Utente IMAP",
-    "IMAP Password" : "Password IMAP",
-    "SMTP Host" : "Host SMTP",
-    "SMTP security" : "Sicurezza SMTP",
-    "SMTP Port" : "Porta SMTP",
-    "SMTP User" : "Utente SMTP",
-    "SMTP Password" : "Password SMTP",
-    "Connect" : "Connetti",
-    "from" : "da",
-    "to" : "a",
-    "cc" : "cc",
-    "bcc" : "ccn",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Nota che il messaggio è arrivato da un indirizzo noreply, perciò la tua risposta non sarà probabilmente letta.",
-    "Subject" : "Oggetto",
-    "Save all to Files" : "Salva tutto in File",
-    "Add mail account" : "Aggiungi account di posta",
-    "Use Gravatar and favicon avatars" : "Utilizza Gravatar e avatar favicon",
-    "No search results for" : "Nessun risultato di ricerca per",
-    "The images have been blocked to protect your privacy." : "Le immagini sono state bloccate per proteggere la tua riservatezza.",
-    "Show images from this sender" : "Mostra immagini da questo mittente",
-    "Forward" : "Inoltra",
-    "No messages in this folder" : "Nessun messaggio in questa cartella",
-    "Upload attachment" : "Carica allegato",
-    "Add attachment from Files" : "Aggiungi allegato da File",
-    "Import into calendar" : "Importa nel calendario",
-    "Download attachment" : "Scarica allegato",
-    "Save to Files" : "Salva in File"
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nuovo messaggio \nda {from}","%n nuovi messaggi \nda {from}"],
+    "Nextcloud Mail" : "Nextcloud Mail",
+    "All inboxes" : "Tutte le caselle di posta",
+    "Could not load {tag}{name}{endtag}" : "Impossibile caricare {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Si è verificato un programma durante il caricamento di {tag}{name}{endtag}",
+    "Could not load the desired message" : "Impossibile caricare messaggio desiderato",
+    "Could not load the message" : "Impossibile caricare il messaggio",
+    "Error loading message" : "Errore durante il caricamento del messaggio",
+    "Forwarding to %s" : "Inoltro a %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Fai clic qui se non viene rediretto automaticamente entro pochi secondi.",
+    "Redirect" : "Redirigi",
+    "The link leads to %s" : "Il collegamento conduce a %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se non vuoi visitare tale pagina, puoi tornare all'<a href=\"%s\">applicazione di posta</a>.",
+    "Continue to %s" : "Continua su %s"
 },
 "nplurals=2; plural=(n != 1);");
