@@ -1,87 +1,89 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Elektroninis paštas",
-    "Loading accounts" : "Įkeliamos paskyros",
-    "Error while loading the accounts." : "Klaida, įkeliant paskyras.",
-    "Can not load this folder." : "Nepavyksta įkelti šio aplanko.",
-    "Searching for {query}" : "Ieškoma {query}",
-    "Error while deleting message." : "Klaida, ištrinant laišką.",
-    "Forwarded message" : "Persiųstas laiškas",
-    "Choose a folder to store the attachment in" : "Pasirinkite aplanką, kuriame išsaugoti priedą",
-    "Attachments saved to Files." : "Priedai įrašyti į Failus.",
-    "Attachment saved to Files." : "Priedas įrašytas į Failus.",
-    "Error while saving attachments to Files." : "Klaida, įrašant priedus į Failus.",
-    "Error while saving attachment to Files." : "Klaida, įrašant priedą į Failus.",
-    "Message flag could not be set." : "Laiškas negali būti pažymėtas",
-    "Could not move message." : "Nepavyko perkelti laiško.",
-    "Invalid account" : "Neteisinga paskyra",
-    "Invalid folder" : "Neteisingas aplankas",
-    "Error while creating the account: " : "Klaida kuriant paskyrą: ",
-    "Unknown error" : "Nežinoma klaida",
-    "Error while updating the account: " : "Klaida atnaujinant paskyrą: ",
-    "All inboxes" : "Visos pašto dėžutės",
-    "you" : "jūs",
-    "Send message to {email}" : "Nusiųsti žinutę į {email}",
-    "Could not load {tag}{name}{endtag}" : "Nepavyko įkelti {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Įvyko klaida bandant parodyti {tag}{name}{endtag}",
-    "Could not load your message" : "Nepavyko įkelti jūsų laiško",
-    "Could not load the desired message" : "Nepavyko įkelti pageidaujamo laiško",
-    "Could not load the message" : "Nepavyko įkelti laiško",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n naujas laiškas \nnuo {from}","%n nauji laiškai \nnuo {from}","%n naujų laiškų \nnuo {from}","%n naujų laiškų \nnuo {from}"],
-    "Nextcloud Mail" : "Nextcloud el. paštas",
-    "Save" : "Įrašyti",
-    "Saved" : "Įrašyta",
-    "Show all folders" : "Rodyti visus aplankus",
-    "Collapse folders" : "Suskleisti aplankus",
-    "Error while deleting account." : "Klaida, ištrinant paskyrą.",
-    "Choose a file to add as attachment" : "Pasirinkite failą, kurį prisegsite prie laiško",
-    "An error occurred while uploading {fname}" : "Įkeliant {fname}, įvyko klaida",
-    "Reply" : "Atsakyti",
-    "Send" : "Siųsti",
-    "Sending …" : "Siunčiama …",
-    "Message sent!" : "Laiškas išsiųstas!",
-    "Server error" : "Serverio klaida",
-    "An unknown error occurred" : "Įvyko nežinoma klaida",
-    "Opening HTML drafts is not supported yet." : "HTML juodraščių atvėrimas kol kas nepalaikomas.",
-    "No writable calendars found" : "Nerasta kalendorių redagavimui",
-    "Error while importing the calendar event" : "Klaida, importuojant kalendoriaus įvykį",
-    "Error while downloading calendar event" : "Klaida, atsisiunčiant kalendoriaus įvykį",
-    "& others" : "ir kiti",
-    "Error while loading messages." : "Klaida, įkeliant laiškus.",
-    "Error while refreshing messages." : "Klaida, atnaujinant laiškus.",
-    "Setting up your account" : "Prijungiama jūsų paskyra",
-    "Inbox" : "Dėžutė",
+    "Mail" : "Paštas",
+    "Inbox" : "Gauta",
     "Sent" : "Išsiųsta",
     "Drafts" : "Juodraščiai",
     "Archive" : "Archyvas",
     "Trash" : "Šiukšlinė",
     "Junk" : "Šlamštas",
     "All" : "Viskas",
-    "Favorites" : "Mėgstamiausi",
+    "Favorites" : "Svarbiausi",
     "Auto detect failed. Please use manual mode." : "Automatinis nustatymų aptikimas nepavyko. Įveskite duomenis rankiniu būdu.",
     "Updating account failed: " : "Paskyros atnaujinimas nepavyko: ",
-    "Creating account failed: " : "Paskyros kūrimas nepavyko:",
+    "Creating account failed: " : "Paskyros sukūrimas nepavyko: ",
     "Delete permanently" : "Ištrinti negrįžtamai",
-    "Error loading message" : "Klaida, įkeliant laišką",
-    "Settings" : "Nustatymai",
-    "Forwarding to %s" : "Persiunčiama į %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Jeigu per artimiausias kelias sekundes nesate automatiškai nukreipiami, spustelėkite čia.",
-    "Redirect" : "Nukreipti",
-    "The link leads to %s" : "Nuoroda veda į %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeigu jūs nenorite lankytis tame puslapyje, galite grįžti į <a href=\"%s\">Paštą</a>.",
-    "Continue to %s" : "Tęsti į %s",
-    "Delete account" : "Ištrinti paskyrą",
-    "Try again" : "Bandykite dar kartą",
-    "New message" : "Naujas laiškas",
-    "Account Settings" : "Paskyros nustatymai",
-    "Aliases" : "Pseudonimai",
-    "Mail address" : "El. pašto adresas",
-    "Display Name" : "Rodomas vardas",
-    "Account" : "Paskyra",
-    "Delete" : "Ištrinti",
+    "IMAP web client" : "IMAP saityno klientas",
+    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Lengvas naudoti el. pašto klientas, kuris prisijungia prie jūsų pašto serverio per IMAP ir SMTP.",
+    "Name" : "Vardas",
+    "Mail Address" : "Elektroninio pašto adresas",
+    "Password" : "Slaptažodis",
+    "IMAP Settings" : "IMAP nustatymai",
+    "IMAP Host" : "IMAP serveris",
+    "IMAP Security" : "IMAP saugumas",
+    "None" : "Nėra",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "IMAP prievadas",
+    "IMAP User" : "IMAP naudotojo vardas",
+    "IMAP Password" : "IMAP slaptažodis",
+    "SMTP Settings" : "SMTP nustatymai",
+    "SMTP Host" : "SMTP serveris",
+    "SMTP Security" : "SMTP saugumas",
+    "SMTP Port" : "SMTP prievadas",
+    "SMTP User" : "SMTP naudotojo vardas",
+    "SMTP Password" : "SMTP slaptažodis",
+    "Save" : "Įrašyti",
+    "Connect" : "Prisijungti",
+    "Add mail account" : "Pridėti pašto paskyrą",
+    "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
     "Keyboard shortcuts" : "Klaviatūros greitieji klavišai",
+    "from" : "nuo",
+    "to" : "kam",
+    "+ cc/bcc" : "+ cc/bcc",
+    "cc" : "cc",
+    "bcc" : "bcc",
+    "Subject" : "Tema",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Turėkite omenyje, kad laiškas atėjo iš adreso, kuris nėra skirtas atsakyti, taigi,\tjūsų atsakymas, tikriausiai, nebus perskaitytas.",
+    "Saving draft …" : "Įrašomas juodraštis …",
+    "Draft saved" : "Juodraštis įrašytas",
+    "Uploading attachments …" : "Įkeliami priedai …",
+    "Sending …" : "Siunčiama …",
+    "Error sending your message" : "Klaida siunčiant jūsų laišką",
+    "Go back" : "Grįžti",
+    "Retry" : "Bandyti dar kartą",
+    "Message sent!" : "Laiškas išsiųstas!",
+    "Reply sent!" : "Atsakymas išsiųstas!",
+    "Write another message" : "Rašyti dar vieną laišką",
+    "Send" : "Siųsti",
+    "Upload attachment" : "Įkelti priedą",
+    "Add attachment from Files" : "Pridėti priedą iš Failų",
+    "Choose a file to add as attachment" : "Pasirinkite failą, kurį prisegsite prie laiško",
+    "No messages in this folder" : "Šiame aplankė pranešimų nėra",
+    "Draft: " : "Juodraštis: ",
+    "Mark read" : "Žymėti kaip skaitytą",
+    "Mark unread" : "Žymėti kaip neskaitytą",
+    "Delete" : "Ištrinti",
+    "Report this bug" : "Pranešti apie šią klaidą",
+    "Loading messages" : "Įkeliami laiškai",
+    "Not found" : "Nerasta",
+    "Could not load your message" : "Nepavyko įkelti jūsų laiško",
+    "Import into calendar" : "Importuoti į kalendorių",
+    "Download attachment" : "Atsisiųsti priedą",
+    "Save to Files" : "Įrašyti į Failus",
+    "Choose a folder to store the attachment in" : "Pasirinkite aplanką, kuriame išsaugoti priedą",
+    "Save all to Files" : "Įrašyti visus į Failus",
+    "Choose a folder to store the attachments in" : "Pasirinkite aplanką, kuriame laikyti priedus",
+    "The images have been blocked to protect your privacy." : "Tam, kad būtų apsaugotas jūsų privatumas, paveikslai buvo užblokuoti.",
+    "Show images from this\tsender" : "Rodyti paveikslus nuo šio\tsiuntėjo",
+    "New message" : "Naujas laiškas",
+    "Settings" : "Nustatymai",
+    "Edit" : "Taisyti",
+    "Show all folders" : "Rodyti visus aplankus",
+    "Collapse folders" : "Suskleisti aplankus",
+    "Could not load your draft" : "Nepavyko įkelti jūsų juodraščio",
+    "Account Settings" : "Paskyros nustatymai",
     "Speed up your Mail experience with these quick shortcuts." : "Padidinkite savo našumą naudodamiesi šiomis nuorodomis.",
     "Compose new message" : "Rašyti naują laišką",
     "Newer message" : "Naujesni laiškai",
@@ -89,43 +91,22 @@ OC.L10N.register(
     "Toggle star" : "Perjungti laiško žymėjimą, kaip pažymėtą žvaigždute",
     "Toggle unread" : "Perjungti laiško žymėjimą, kaip neskaityto",
     "Search" : "Ieškoti",
-    "Refresh" : "Atnaujinti",
+    "Refresh" : "Įkelti iš naujo",
     "Connect your mail account" : "Priregistruoti elektroninio pašto paskyrą",
-    "Name" : "Vardas",
-    "Mail Address" : "Elektroninio pašto adresas",
-    "Password" : "Slaptažodis",
-    "Manual configuration" : "Rankinė konfigūracija",
-    "IMAP Host" : "IMAP serveris",
-    "IMAP security" : "IMAP saugumas",
-    "None" : "Joks",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "IMAP prievadas",
-    "IMAP User" : "IMAP naudotojo vardas",
-    "IMAP Password" : "IMAP slaptažodis",
-    "SMTP Host" : "SMTP serveris",
-    "SMTP security" : "SMTP saugumas",
-    "SMTP Port" : "SMTP prievadas",
-    "SMTP User" : "SMTP naudotojo vardas",
-    "SMTP Password" : "SMTP slaptažodis",
-    "Connect" : "Prisijungti",
-    "from" : "nuo",
-    "to" : "į",
-    "cc" : "cc",
-    "bcc" : "bcc",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Turėkite omenyje, kad laiškas atėjo iš adreso, kuris nėra skirtas atsakyti, taigi jūsų atsakymas, tikriausiai, nebus perskaitytas.",
-    "Subject" : "Tema",
-    "Save all to Files" : "Įrašyti visus į Failus",
-    "Add mail account" : "Pridėti pašto paskyrą",
-    "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
-    "No search results for" : "Nėra paieškos rezultatų, skirtų",
-    "The images have been blocked to protect your privacy." : "Tam, kad būtų apsaugotas jūsų privatumas, paveikslai buvo užblokuoti.",
-    "Show images from this sender" : "Rodyti paveikslus nuo šio siuntėjo",
-    "Forward" : "Persiųsti",
-    "No messages in this folder" : "Šiame aplankė pranešimų nėra",
-    "Upload attachment" : "Įkelti priedą",
-    "Add attachment from Files" : "Pridėti priedą iš Failų",
-    "Import into calendar" : "Importuoti į kalendorių",
-    "Download attachment" : "Atsisiųsti priedą",
-    "Save to Files" : "Įrašyti į Failus"
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n naujas laiškas \nnuo {from}","%n nauji laiškai \nnuo {from}","%n naujų laiškų \nnuo {from}","%n naujų laiškų \nnuo {from}"],
+    "Nextcloud Mail" : "Nextcloud el. paštas",
+    "All inboxes" : "Visos pašto dėžutės",
+    "Could not load {tag}{name}{endtag}" : "Nepavyko įkelti {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Įvyko klaida bandant parodyti {tag}{name}{endtag}",
+    "Could not load the desired message" : "Nepavyko įkelti pageidaujamo laiško",
+    "Could not load the message" : "Nepavyko įkelti laiško",
+    "Error loading message" : "Klaida, įkeliant laišką",
+    "Forwarding to %s" : "Persiunčiama į %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Jeigu per artimiausias kelias sekundes nesate automatiškai nukreipiami, spustelėkite čia.",
+    "Redirect" : "Nukreipti",
+    "The link leads to %s" : "Nuoroda veda į %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeigu jūs nenorite lankytis tame puslapyje, galite grįžti į <a href=\"%s\">Paštą</a>.",
+    "Continue to %s" : "Tęsti į %s"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
