@@ -2,62 +2,12 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "E-mail",
-    "Loading accounts" : "Accounts laden",
-    "Error while loading the accounts." : "Fout tijdens het laden van de accounts.",
-    "Can not load this folder." : "Kan deze map niet laden.",
-    "Searching for {query}" : "Zoeken naar {query}",
-    "Error while deleting message." : "Fout bij verwijderen bericht.",
-    "Forwarded message" : "Doorgestuurd bericht",
-    "Choose a folder to store the attachment in" : "Kies een map op de bijlage in op te slaan",
-    "Attachments saved to Files." : "Bjilagen opgeslagen in Bestanden.",
-    "Attachment saved to Files." : "Bijlage opgeslagen in Bestanden.",
-    "Error while saving attachments to Files." : "Fout bij opslaan bijlagen in Bestanden.",
-    "Error while saving attachment to Files." : "Fout bij opslaan bijlage in Bestanden.",
-    "Message flag could not be set." : "Bericht kon niet als gemarkeerd worden.",
-    "Could not move message." : "Kon bericht niet verplaatsen",
-    "Invalid account" : "Ongeldig account",
-    "Invalid folder" : "Ongeldige map",
-    "Error while creating the account: " : "Fout bij het creëren van een account:",
-    "Unknown error" : "Onbekende fout",
-    "Error while updating the account: " : "Fout tijdens het bijwerken van account:",
-    "All inboxes" : "Alle postvakken",
-    "you" : "jou",
-    "Send message to {email}" : "Verstuur email aan {email}",
-    "Could not load {tag}{name}{endtag}" : "Kon niet laden {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Er is een probleem bij het laden {tag}{name}{endtag}",
-    "Could not load your message" : "Kon je bericht niet laden",
-    "Could not load the desired message" : "Kon het gewenste bericht niet laden",
-    "Could not load the message" : "Kon het bericht niet laden",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nieuw bericht \nvan {from}","%n niewe berichten \nvan {from}"],
-    "Nextcloud Mail" : "Nextcloud E-mail",
-    "Save" : "Opslaan",
-    "Saved" : "Opgeslagen",
-    "Show all folders" : "Laat alle mappen zien",
-    "Collapse folders" : "Mappen inklappen",
-    "Error while deleting account." : "Fout bij verwijderen account.",
-    "Choose a file to add as attachment" : "Kies een bestand om als bijlage toe te voegen",
-    "An error occurred while uploading {fname}" : "Er trad een fout op bij het uploaden van {fname}",
-    "Reply" : "Antwoord",
-    "Send" : "Versturen",
-    "Sending …" : "Versturen ...",
-    "Message sent!" : "Bericht verzonden!",
-    "Server error" : "Serverfout",
-    "An unknown error occurred" : "Een onbekend probleem vond plaats",
-    "Opening HTML drafts is not supported yet." : "Openen concept HTML wordt nog niet ondersteund.",
-    "No writable calendars found" : "Geen beschijfbare agenda's gevonden",
-    "Error while importing the calendar event" : "Fout bij importeren agenda-afspraak",
-    "Error while downloading calendar event" : "Fout bij downloaden agenda-afspraak",
-    "& others" : "& anderen",
-    "Error while loading messages." : "Fout bij laden berichten.",
-    "Error while refreshing messages." : "Foutmelding tijdens verversen van berichten.",
-    "Setting up your account" : "Je account opzetten",
     "Inbox" : "Postvak in",
     "Sent" : "Verzonden",
     "Drafts" : "Concepten",
     "Archive" : "Archief",
     "Trash" : "Verwijderen",
-    "Junk" : "Afval",
+    "Junk" : "Ongewenst",
     "All" : "Alle",
     "Favorites" : "Favorieten",
     "Auto detect failed. Please use manual mode." : "Automatisch vaststellen mislukt. Gebruik handmatige modus.",
@@ -66,25 +16,83 @@ OC.L10N.register(
     "Delete permanently" : "Definitief verwijderen",
     "IMAP web client" : "IMAP web client",
     "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Gebruiksvriendelijke e-mailclient die verbindt met je mailserver via IMAP en SMTP.",
-    "Error loading message" : "Fout bij laden bericht",
-    "Settings" : "Instellingen",
-    "Forwarding to %s" : "Doorsturen aan %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier als je binnen enkele seconden niet automatisch wordt doorgestuurd.",
-    "Redirect" : "Omleiden",
-    "The link leads to %s" : "De link verwijst naar %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Als je die pagina niet wilt bezoeken, kun je teruggaan naar <a href=\"%s\">E-mail</a>.",
-    "Continue to %s" : "Verder naar %s",
-    "Delete account" : "Verwijder account",
-    "Try again" : "Probeer opnieuw",
-    "New message" : "Nieuw bericht",
-    "Account Settings" : "Account instellingen",
-    "Aliases" : "Aliassen",
-    "Mail address" : "E-mailadres",
-    "Display Name" : "Weergavenaam",
-    "Account" : "Account",
-    "Toggle read" : "Omschakelen leesmodus",
-    "Delete" : "Verwijderen",
+    "Auto" : "Automatisch",
+    "Name" : "Naam",
+    "Mail Address" : "E-mailadres",
+    "Password" : "Wachtwoord",
+    "Manual" : "Handmatig",
+    "IMAP Settings" : "IMAP instellingen",
+    "IMAP Host" : "IMAP host",
+    "IMAP Security" : "IMAP beveiliging",
+    "None" : "Geen",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "IMAP poort",
+    "IMAP User" : "IMAP gebruikersnaam",
+    "IMAP Password" : "IMAP wachtwoord",
+    "SMTP Settings" : "SMTP instellingen",
+    "SMTP Host" : "SMTP host",
+    "SMTP Security" : "SMTP beveiliging",
+    "SMTP Port" : "SMTP poort",
+    "SMTP User" : "SMTP gebruikersnaam",
+    "SMTP Password" : "SMTP wachtwoord",
+    "Save" : "Bewaren",
+    "Connect" : "Verbinden",
+    "Add mail account" : "Voeg e-mail account toe",
+    "Use Gravatar and favicon avatars" : "Gebruik Gravatar en favicon avatars",
     "Keyboard shortcuts" : "Sneltoetsen",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Op zoek naar een manier om je emails te versleutelen? Installeer de Mailvelope extensie in je browser!",
+    "from" : "van",
+    "to" : "aan",
+    "+ cc/bcc" : "+ cc/bcc",
+    "cc" : "cc",
+    "bcc" : "bcc",
+    "Subject" : "Onderwerp",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Let op! Het bericht komt van een \"noreply\" adres\tjouw antwoord zal waarschijnlijk niet worden gelezen.",
+    "Message …" : "Bericht ...",
+    "Saving draft …" : "Concept aan het opslaan ...",
+    "Draft saved" : "Concept opgeslagen",
+    "Uploading attachments …" : "Bijlage aan het uploaden ...",
+    "Sending …" : "Versturen ...",
+    "Error sending your message" : "Fout bij het versturen van jouw bericht",
+    "Go back" : "Ga terug",
+    "Retry" : "Opnieuw proberen",
+    "Message sent!" : "Bericht verzonden!",
+    "Reply sent!" : "Antwoord verzonden!",
+    "Write another message" : "Schrijf nog een bericht",
+    "Send" : "Versturen",
+    "Uploading {percent}% …" : "Uploaden {percent}% …",
+    "Upload attachment" : "Bijlage uploaden",
+    "Add attachment from Files" : "Bijlage toevoegen vanuit Bestanden",
+    "Choose a file to add as attachment" : "Kies een bestand om als bijlage toe te voegen",
+    "No messages in this folder" : "Geen berichten in deze map",
+    "Draft: " : "Concept:",
+    "Mark read" : "Markeer gelezen",
+    "Mark unread" : "Markeer ongelezen",
+    "Delete" : "Verwijderen",
+    "Report this bug" : "Meld deze fout",
+    "Loading messages" : "Berichten aan het laden",
+    "Not found" : "Niet gevonden",
+    "Could not load your message" : "Kon je bericht niet laden",
+    "Import into calendar" : "Toevoegen aan agenda",
+    "Download attachment" : "Download bijlage",
+    "Save to Files" : "Opslaan in Bestanden",
+    "Choose a folder to store the attachment in" : "Kies een map op de bijlage in op te slaan",
+    "Save all to Files" : "Sla alles op in Bestanden",
+    "Choose a folder to store the attachments in" : "Selecteer een folder waarin de bijlagen opgeslagen moeten worden",
+    "The images have been blocked to protect your privacy." : "De afbeeldingen zijn geblokkeerd om je privacy te beschermen",
+    "Show images from this\tsender" : "Toon afbeeldingen van deze\tzender",
+    "New message" : "Nieuw bericht",
+    "Settings" : "Instellingen",
+    "Edit" : "Bewerken",
+    "Show all folders" : "Laat alle mappen zien",
+    "Collapse folders" : "Mappen inklappen",
+    "Could not load your draft" : "Kan jouw concept niet laden",
+    "No message selected" : "Geen bericht geselecteerd",
+    "Signature" : "Handtekening",
+    "A signature will be added to the text of new and response messages." : "Een handtekening zal worden toegevoegd aan nieuwe emails en antwoorden.",
+    "Account Settings" : "Accountinstellingen",
+    "Mail server" : "Mailserver",
     "Speed up your Mail experience with these quick shortcuts." : "Versnel je e-mail-ervaring met deze handige snelkoppelingen.",
     "Compose new message" : "Opstellen nieuw bericht",
     "Newer message" : "Recenter bericht",
@@ -94,41 +102,20 @@ OC.L10N.register(
     "Search" : "Zoeken",
     "Refresh" : "Verversen",
     "Connect your mail account" : "verbind je e-mailaccount",
-    "Name" : "Naam",
-    "Mail Address" : "E-mailadres",
-    "Password" : "Wachtwoord",
-    "Manual configuration" : "Handmatig configureren",
-    "IMAP Host" : "IMAP host",
-    "IMAP security" : "IMAP security",
-    "None" : "Geen",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "IMAP poort",
-    "IMAP User" : "IMAP gebruikersnaam",
-    "IMAP Password" : "IMAP wachtwoord",
-    "SMTP Host" : "SMTP host",
-    "SMTP security" : "SMTP security",
-    "SMTP Port" : "SMTP poort",
-    "SMTP User" : "SMTP gebruikersnaam",
-    "SMTP Password" : "SMTP wachtwoord",
-    "Connect" : "Verbinden",
-    "from" : "van",
-    "to" : "aan",
-    "cc" : "cc",
-    "bcc" : "bcc",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Let op: het e-mailbericht kwam van een niet-antwoord adres, waardoor je antwoord vermoedelijk niet zal worden gelezen.",
-    "Subject" : "Onderwerp",
-    "Save all to Files" : "Sla alles op in Bestanden",
-    "Add mail account" : "Voeg e-mail account toe",
-    "Use Gravatar and favicon avatars" : "Gebruik Gravatar en favicon avatars",
-    "No search results for" : "Geen resultaten gevonden voor",
-    "The images have been blocked to protect your privacy." : "De afbeeldingen zijn geblokkeerd om je privacy te beschermen",
-    "Show images from this sender" : "Laat afbeeldingen zien van deze afzender",
-    "Forward" : "Doorsturen",
-    "No messages in this folder" : "Geen berichten in deze map",
-    "Upload attachment" : "Bijlage uploaden",
-    "Add attachment from Files" : "Bijlage toevoegen vanuit Bestanden",
-    "Import into calendar" : "Toevoegen aan agenda",
-    "Download attachment" : "Download bijlage",
-    "Save to Files" : "Opslaan in Bestanden"
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nieuw bericht \nvan {from}","%n niewe berichten \nvan {from}"],
+    "Nextcloud Mail" : "Nextcloud E-mail",
+    "All inboxes" : "Alle postvakken",
+    "Could not load {tag}{name}{endtag}" : "Kon niet laden {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Er is een probleem bij het laden {tag}{name}{endtag}",
+    "Could not load the desired message" : "Kon het gewenste bericht niet laden",
+    "Could not load the message" : "Kon het bericht niet laden",
+    "Error loading message" : "Fout bij laden bericht",
+    "Forwarding to %s" : "Doorsturen aan %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier als je binnen enkele seconden niet automatisch wordt doorgestuurd.",
+    "Redirect" : "Omleiden",
+    "The link leads to %s" : "De link verwijst naar %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Als je die pagina niet wilt bezoeken, kun je teruggaan naar <a href=\"%s\">E-mail</a>.",
+    "Continue to %s" : "Verder naar %s"
 },
 "nplurals=2; plural=(n != 1);");
