@@ -2,56 +2,6 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Poczta",
-    "Loading accounts" : "Ładowanie kont",
-    "Error while loading the accounts." : "Błąd podczas ładowania kont.",
-    "Can not load this folder." : "Nie można załadować tego folderu.",
-    "Searching for {query}" : "Wyszukiwanie {query}",
-    "Error while deleting message." : "Błąd podczas usuwania wiadomości.",
-    "Forwarded message" : "Wiadomość przekazana",
-    "Choose a folder to store the attachment in" : "Proszę wybrać folder do zapisania załącznika",
-    "Attachments saved to Files." : "Załączniki zapisane do plików.",
-    "Attachment saved to Files." : "Załącznik zapisany do plików.",
-    "Error while saving attachments to Files." : "Błąd podczas zapisu załączników do plików.",
-    "Error while saving attachment to Files." : "Błąd podczas zapisu załącznika do plików.",
-    "Message flag could not be set." : "Nie można oznaczyć wiadomości.",
-    "Could not move message." : "Nie można przenieść wiadomości.",
-    "Invalid account" : "Nieprawidłowe konto",
-    "Invalid folder" : "Nieprawidłowy folder",
-    "Error while creating the account: " : "Błąd podczas tworzenia konta:",
-    "Unknown error" : "Nieznany błąd",
-    "Error while updating the account: " : "Błąd podczas aktualizacji konta: ",
-    "All inboxes" : "Wszystkie skrzynki odbiorcze",
-    "you" : "Ty",
-    "Send message to {email}" : "Wyślij wiadomość do {email}",
-    "Could not load {tag}{name}{endtag}" : "Nie można załadować {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Wystąpił problem podczas wczytywania {tag}{name}{endtag}",
-    "Could not load your message" : "Nie można załadować wiadomości",
-    "Could not load the desired message" : "Nie można wczytać żądanej wiadomości",
-    "Could not load the message" : "Nie można załadować wiadomości",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nowa wiadomość\nod {from}","%n nowe wiadomości \nod {from}","%n nowych wiadomości \nod {from}","%n nowych wiadomości \nod {from}"],
-    "Nextcloud Mail" : "Poczta Nextcloud",
-    "Save" : "Zapisz",
-    "Saved" : "Zapisano",
-    "Show all folders" : "Wyświetl wszystkie foldery",
-    "Collapse folders" : "Zwiń foldery",
-    "Error while deleting account." : "Błąd podczas usuwania konta.",
-    "Choose a file to add as attachment" : "Wybierz plik aby dodać jako załącznik",
-    "An error occurred while uploading {fname}" : "Wystąpił błąd podczas wysyłania {fname}",
-    "Reply" : "Odpowiedz",
-    "Send" : "Wyślij",
-    "Sending …" : "Wysyłanie…",
-    "Message sent!" : "Wiadomość wysłana!",
-    "Server error" : "Błąd serwera",
-    "An unknown error occurred" : "Wystąpił nieznany błąd",
-    "Opening HTML drafts is not supported yet." : "Otwieranie wiadomości roboczych w HTML nie jest jeszcze wspierane.",
-    "No writable calendars found" : "Nie znaleziono zapisywalnych kalendarzy.",
-    "Error while importing the calendar event" : "Wystąpił błąd podczas importowania zdarzenia z kalendarza",
-    "Error while downloading calendar event" : "Wystąpił błąd podczas pobierania zdarzenia z kalendarza",
-    "& others" : "& inni",
-    "Error while loading messages." : "Błąd podczas ładowania wiadomości.",
-    "Error while refreshing messages." : "Błąd podczas odświeżania wiadomości.",
-    "Setting up your account" : "Skonfiguruj swoje konto",
     "Inbox" : "Odbiorcza",
     "Sent" : "Wysłane",
     "Drafts" : "Szkice",
@@ -66,25 +16,83 @@ OC.L10N.register(
     "Delete permanently" : "Trwale usuń",
     "IMAP web client" : "Klient webowy IMAP",
     "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Łatwy w użytkowaniu klient IMAP i SMTP, który łączy się z Twoim serwerem pocztowym.",
-    "Error loading message" : "Błąd podczas ładowania wiadomości",
-    "Settings" : "Ustawienia",
-    "Forwarding to %s" : "Prześlij do %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Kliknij tutaj, jeśli nie są automatycznie przekierowywane w ciągu kilku sekund.",
-    "Redirect" : "Przekieruj",
-    "The link leads to %s" : "Link prowadzi do %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeśli nie chcesz odwiedzić tej strony, możesz powrócić do <a href=\"%s\">Poczty</a>.",
-    "Continue to %s" : "Kontynuuj do %s",
-    "Delete account" : "Usuń konto",
-    "Try again" : "Spróbuj ponownie",
-    "New message" : "Nowa wiadomość",
-    "Account Settings" : "Ustawienia konta",
-    "Aliases" : "Aliasy",
-    "Mail address" : "Adres mailowy",
-    "Display Name" : "Wyświetlana nazwa",
-    "Account" : "Konto",
-    "Toggle read" : "Oznacz jako przeczytane/nieprzeczytane",
-    "Delete" : "Usuń",
+    "Auto" : "Automatycznie",
+    "Name" : "Nazwa",
+    "Mail Address" : "Adres mailowy",
+    "Password" : "Hasło",
+    "Manual" : "Ustawienia własne",
+    "IMAP Settings" : "Ustawienia IMAP",
+    "IMAP Host" : "IMAP Host",
+    "IMAP Security" : "Zabezpieczenia IMAP",
+    "None" : "Brak",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "Port IMAP",
+    "IMAP User" : "Użytkownik IMAP",
+    "IMAP Password" : "Hasło IMAP",
+    "SMTP Settings" : "Ustawienia SMTP",
+    "SMTP Host" : "SMTP Host",
+    "SMTP Security" : "Zabezpieczenia SMTP",
+    "SMTP Port" : "Port SMTP",
+    "SMTP User" : "Użytkownik SMTP",
+    "SMTP Password" : "Hasło SMTP",
+    "Save" : "Zapisz",
+    "Connect" : "Połącz",
+    "Add mail account" : "Dodaj konto mailowe",
+    "Use Gravatar and favicon avatars" : "Używaj awatarów Gravatar i favicon",
     "Keyboard shortcuts" : "Skróty klawiaturowe",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Szukasz sposobu na szyfrowanie swoich wiadomosci? Zainstaluj rozszerzenie Mailvelope do przeglądarki!",
+    "from" : "od",
+    "to" : "do",
+    "+ cc/bcc" : "+ DW/UDW",
+    "cc" : "cc",
+    "bcc" : "bcc",
+    "Subject" : "Temat",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Zwróć uwagę, że wiadomość została wysłana z adresu nie przyjmującego odpowiedzi\tdlatego twoja odpowiedź prawdopodobnie nie zostanie odczytana.",
+    "Message …" : "Wiadomość ...",
+    "Saving draft …" : "Zapisuję szkic ...",
+    "Draft saved" : "Szkic zapisany",
+    "Uploading attachments …" : "Wysyłanie załączników ...",
+    "Sending …" : "Wysyłanie…",
+    "Error sending your message" : "W trakcie wysyłania wiadomości wystąpił błąd",
+    "Go back" : "Powrót",
+    "Retry" : "Powtórz",
+    "Message sent!" : "Wiadomość wysłana!",
+    "Reply sent!" : "Odpowiedź została wysłana!",
+    "Write another message" : "Utwórz kolejną wiadomość",
+    "Send" : "Wyślij",
+    "Uploading {percent}% …" : "Wysłane {percent}%…",
+    "Upload attachment" : "Dodaj załącznik",
+    "Add attachment from Files" : "Dodaj załącznik z Pliki",
+    "Choose a file to add as attachment" : "Wybierz plik aby dodać jako załącznik",
+    "No messages in this folder" : "Brak wiadomości w tym folderze",
+    "Draft: " : "Szkic:",
+    "Mark read" : "Oznacz jako przeczytana",
+    "Mark unread" : "Oznacz jako nie przeczytana",
+    "Delete" : "Usuń",
+    "Report this bug" : "Zgłoś ten błąd",
+    "Loading messages" : "Pobieranie wiadomości",
+    "Not found" : "Nie odnaleziono",
+    "Could not load your message" : "Nie można załadować wiadomości",
+    "Import into calendar" : "Importuj do kalendarza",
+    "Download attachment" : "Pobierz załącznik",
+    "Save to Files" : "Zapisz do plików",
+    "Choose a folder to store the attachment in" : "Proszę wybrać folder do zapisania załącznika",
+    "Save all to Files" : "Zapisz wszystko do plików",
+    "Choose a folder to store the attachments in" : "Wybierz folder do zapisywania załączników",
+    "The images have been blocked to protect your privacy." : "Obrazy zostały zablokowane by chronić Twoją prywatność.",
+    "Show images from this\tsender" : "Wyświetl zdalną zawartość od\tnadawcy",
+    "New message" : "Nowa wiadomość",
+    "Settings" : "Ustawienia",
+    "Edit" : "Edycja",
+    "Show all folders" : "Wyświetl wszystkie foldery",
+    "Collapse folders" : "Zwiń foldery",
+    "Could not load your draft" : "Nie można wczytać szkicu wiadomości",
+    "No message selected" : "Nie wybrano żadnej wiadomości",
+    "Signature" : "Podpis",
+    "A signature will be added to the text of new and response messages." : "Podpis będzie dodany do nowych i zwrotnych wiadomości.",
+    "Account Settings" : "Ustawienia konta",
+    "Mail server" : "Serwer pocztowy",
     "Speed up your Mail experience with these quick shortcuts." : "Aby przyspieszyć korzystanie z Poczty użyj tych skrótów.",
     "Compose new message" : "Napisz nową wiadomość",
     "Newer message" : "Nowsza wiadomość",
@@ -94,41 +102,20 @@ OC.L10N.register(
     "Search" : "Szukaj",
     "Refresh" : "Odśwież",
     "Connect your mail account" : "Podłącz konto pocztowe",
-    "Name" : "Nazwa",
-    "Mail Address" : "Adres mailowy",
-    "Password" : "Hasło",
-    "Manual configuration" : "Ręczna konfiguracja",
-    "IMAP Host" : "IMAP Host",
-    "IMAP security" : "zabezpieczenie IMAP",
-    "None" : "Brak",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "Port IMAP",
-    "IMAP User" : "Użytkownik IMAP",
-    "IMAP Password" : "Hasło IMAP",
-    "SMTP Host" : "SMTP Host",
-    "SMTP security" : "zabezpieczenie SMTP",
-    "SMTP Port" : "Port SMTP",
-    "SMTP User" : "Użytkownik SMTP",
-    "SMTP Password" : "Hasło SMTP",
-    "Connect" : "Połącz",
-    "from" : "od",
-    "to" : "do",
-    "cc" : "cc",
-    "bcc" : "bcc",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Zauważ, że mail przyszedł z adresu noreply, stąd Twoja odpowiedź na tą wiadomość prawdopodobnie nie zostanie odczytana.",
-    "Subject" : "Temat",
-    "Save all to Files" : "Zapisz wszystko do plików",
-    "Add mail account" : "Dodaj konto mailowe",
-    "Use Gravatar and favicon avatars" : "Używaj awatarów Gravatar i favicon",
-    "No search results for" : "Brak wyników wyszukiwania",
-    "The images have been blocked to protect your privacy." : "Obrazy zostały zablokowane by chronić Twoją prywatność.",
-    "Show images from this sender" : "Zobacz zdjęcia od tego nadawcy",
-    "Forward" : "Prześlij dalej",
-    "No messages in this folder" : "Brak wiadomości w tym folderze",
-    "Upload attachment" : "Dodaj załącznik",
-    "Add attachment from Files" : "Dodaj załącznik z Pliki",
-    "Import into calendar" : "Importuj do kalendarza",
-    "Download attachment" : "Pobierz załącznik",
-    "Save to Files" : "Zapisz do plików"
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nowa wiadomość\nod {from}","%n nowe wiadomości \nod {from}","%n nowych wiadomości \nod {from}","%n nowych wiadomości \nod {from}"],
+    "Nextcloud Mail" : "Poczta Nextcloud",
+    "All inboxes" : "Wszystkie skrzynki odbiorcze",
+    "Could not load {tag}{name}{endtag}" : "Nie można załadować {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Podczas ładowania wystąpił problem {tag}{name}{endtag}",
+    "Could not load the desired message" : "Nie można wczytać żądanej wiadomości",
+    "Could not load the message" : "Nie można załadować wiadomości",
+    "Error loading message" : "Błąd podczas ładowania wiadomości",
+    "Forwarding to %s" : "Prześlij do %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Kliknij tutaj, jeśli nie są automatycznie przekierowywane w ciągu kilku sekund.",
+    "Redirect" : "Przekieruj",
+    "The link leads to %s" : "Link prowadzi do %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeśli nie chcesz odwiedzić tej strony, możesz powrócić do <a href=\"%s\">Poczty</a>.",
+    "Continue to %s" : "Kontynuuj do %s"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
