@@ -2,56 +2,6 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "E-mail",
-    "Loading accounts" : "Carregando contas",
-    "Error while loading the accounts." : "Erro ao carregar as contas.",
-    "Can not load this folder." : "Não foi possível carregar esta pasta.",
-    "Searching for {query}" : "Pesquisando por {query}",
-    "Error while deleting message." : "Erro ao excluir mensagem.",
-    "Forwarded message" : "Mensagem encaminhada",
-    "Choose a folder to store the attachment in" : "Escolha uma pasta para armazenar os anexos",
-    "Attachments saved to Files." : "Anexo salvos em Arquivos.",
-    "Attachment saved to Files." : "Anexo salvo em Arquivos.",
-    "Error while saving attachments to Files." : "Erro ao salvar anexos em Arquivos.",
-    "Error while saving attachment to Files." : "Erro ao salvar anexos em Arquivos.",
-    "Message flag could not be set." : "Marcação da mensagem não pôde ser definida.",
-    "Could not move message." : "Não foi possível mover a mensagem.",
-    "Invalid account" : "Conta inválida",
-    "Invalid folder" : "Pasta inválida",
-    "Error while creating the account: " : "Erro ao criar a conta:",
-    "Unknown error" : "Erro desconhecido",
-    "Error while updating the account: " : "Erro ao atualizar a conta:",
-    "All inboxes" : "Todas as caixas de entrada",
-    "you" : "você",
-    "Send message to {email}" : "Enviar mensagem para {email}",
-    "Could not load {tag}{name}{endtag}" : "Não foi possível carregar {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Ocorreu um problema ao carregar {tag}{name}{endtag}",
-    "Could not load your message" : "Não foi possível carregar sua mensagem",
-    "Could not load the desired message" : "Não foi possível carregar a mensagem desejada",
-    "Could not load the message" : "Não foi possível carregar a mensagem",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mensagem \nde {from}","%n novas mensagens \nde {from}"],
-    "Nextcloud Mail" : "E-mail Nextcloud",
-    "Save" : "Salvar",
-    "Saved" : "Salvo",
-    "Show all folders" : "Mostrar todas as pastas",
-    "Collapse folders" : "Esconder as pastas",
-    "Error while deleting account." : "Erro ao excluir a conta.",
-    "Choose a file to add as attachment" : "Escolha um arquivo para adicionar como anexo",
-    "An error occurred while uploading {fname}" : "Um erro ocorreu ao enviar {fname}",
-    "Reply" : "Responder",
-    "Send" : "Enviar",
-    "Sending …" : "Enviando...",
-    "Message sent!" : "Mensagem enviada!",
-    "Server error" : "Erro no servidor",
-    "An unknown error occurred" : "Ocorreu um erro desconhecido",
-    "Opening HTML drafts is not supported yet." : "A abertura de rascunhos do HTML ainda não é suportada.",
-    "No writable calendars found" : "Não foi encontrado nenhum calendário que possa ser editado",
-    "Error while importing the calendar event" : "Erro ao importar o evento de calendário",
-    "Error while downloading calendar event" : "Erro ao baixar evento de calendário",
-    "& others" : "& outros",
-    "Error while loading messages." : "Erro ao carregar mensagens.",
-    "Error while refreshing messages." : "Erro ao atualizar as mensagens.",
-    "Setting up your account" : "Configurando sua conta",
     "Inbox" : "Caixa de Entrada",
     "Sent" : "Enviados",
     "Drafts" : "Rascunhos",
@@ -66,25 +16,83 @@ OC.L10N.register(
     "Delete permanently" : "Excluir permanentemente",
     "IMAP web client" : "Cliente web IMAP",
     "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Cliente de e-mail fácil de usar que se conecta ao seu servidor de e-mail via IMAP e SMTP.",
-    "Error loading message" : "Erro carregando mensagem",
-    "Settings" : "Configurações",
-    "Forwarding to %s" : "Encaminhando para %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se você não for redirecionado automaticamente em alguns segundos",
-    "Redirect" : "Redirecionar",
-    "The link leads to %s" : "O link leva a %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se você não quiser visitar essa página, você pode retornar ao <a href=\"%s\">e-mail</a>.",
-    "Continue to %s" : "Continue para %s",
-    "Delete account" : "Excluir conta",
-    "Try again" : "Tentar novamente",
-    "New message" : "Nova mensagem",
-    "Account Settings" : "Configurações de conta",
-    "Aliases" : "Apelido",
-    "Mail address" : "Endereço de e-mail",
-    "Display Name" : "Nome",
-    "Account" : "Conta",
-    "Toggle read" : "Alternar leitura",
-    "Delete" : "Excluir",
+    "Auto" : "Automático",
+    "Name" : "Nome",
+    "Mail Address" : "Endereço de e-mail",
+    "Password" : "Senha",
+    "Manual" : "Manual",
+    "IMAP Settings" : "Configuração IMAP",
+    "IMAP Host" : "Host IMAP",
+    "IMAP Security" : "Segurança IMAP",
+    "None" : "Não",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "Porto IMAP",
+    "IMAP User" : "Usuário IMAP",
+    "IMAP Password" : "Senha IMAP",
+    "SMTP Settings" : "Configuração SMTP",
+    "SMTP Host" : "Host SMTP",
+    "SMTP Security" : "Segurança SMTP",
+    "SMTP Port" : "Porto SMTP",
+    "SMTP User" : "Usuário SMTP",
+    "SMTP Password" : "Senha SMTP",
+    "Save" : "Salvar",
+    "Connect" : "Conectar",
+    "Add mail account" : "Adicionar conta de e-mail",
+    "Use Gravatar and favicon avatars" : "Usar Gravatar e avatares para favicon",
     "Keyboard shortcuts" : "Atalhos de teclado",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Procurando uma maneira de criptografar seus e-mails? Instale a extensão de navegador Mailvelope!",
+    "from" : "de",
+    "to" : "para",
+    "+ cc/bcc" : "+ cc/bcc",
+    "cc" : "cc",
+    "bcc" : "cco",
+    "Subject" : "Assunto",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Observe que veio de um endereço noreply então\tsua resposta não será lida.",
+    "Message …" : "Mensagem...",
+    "Saving draft …" : "Salvando rascunho...",
+    "Draft saved" : "Rascunho salvo",
+    "Uploading attachments …" : "Enviando anexos...",
+    "Sending …" : "Enviando...",
+    "Error sending your message" : "Erro ao enviar sua mensagem",
+    "Go back" : "Voltar",
+    "Retry" : "Retentar",
+    "Message sent!" : "Mensagem enviada!",
+    "Reply sent!" : "Resposta enviada!",
+    "Write another message" : "Escrever outra mensagem",
+    "Send" : "Enviar",
+    "Uploading {percent}% …" : "Enviando {percent}%…",
+    "Upload attachment" : "Enviar anexo",
+    "Add attachment from Files" : "Adicionar anexo a partir de arquivos",
+    "Choose a file to add as attachment" : "Escolha um arquivo para adicionar como anexo",
+    "No messages in this folder" : "Sem mensagens nesta pasta",
+    "Draft: " : "Rascunho:",
+    "Mark read" : "Marcar como lida",
+    "Mark unread" : "Marcar como não lida",
+    "Delete" : "Excluir",
+    "Report this bug" : "Reportar este erro",
+    "Loading messages" : "Carregando mensagens",
+    "Not found" : "Não encontrado",
+    "Could not load your message" : "Não foi possível carregar sua mensagem",
+    "Import into calendar" : "Importar para o calendário",
+    "Download attachment" : "Baixar anexo",
+    "Save to Files" : "Salvar para arquivos",
+    "Choose a folder to store the attachment in" : "Escolha uma pasta para armazenar os anexos",
+    "Save all to Files" : "Salvar tudo para Arquivos",
+    "Choose a folder to store the attachments in" : "Escolha uma pasta para armazenar os anexos",
+    "The images have been blocked to protect your privacy." : "As imagens foram bloqueadas para proteger sua privacidade",
+    "Show images from this\tsender" : "Exibir imagens deste\tremetente",
+    "New message" : "Nova mensagem",
+    "Settings" : "Configurações",
+    "Edit" : "Editar",
+    "Show all folders" : "Exibir todas as pastas",
+    "Collapse folders" : "Esconder as pastas",
+    "Could not load your draft" : "Não pude carregar seu rascunho",
+    "No message selected" : "Nenhuma mensagem selecionada",
+    "Signature" : "Assinatura",
+    "A signature will be added to the text of new and response messages." : "Uma assinatura será adicionada ao texto das mensagens novas e respostas.",
+    "Account Settings" : "Configurações da Conta",
+    "Mail server" : "Servidor de e-mail",
     "Speed up your Mail experience with these quick shortcuts." : "Acelere o uso de seu e-mail com estes atalhos rápidos.",
     "Compose new message" : "Redigir nova mensagem",
     "Newer message" : "Mensagem mais recente",
@@ -94,41 +102,20 @@ OC.L10N.register(
     "Search" : "Pesquisar",
     "Refresh" : "Atualizar",
     "Connect your mail account" : "Conectar sua conta de e-mail",
-    "Name" : "Nome",
-    "Mail Address" : "Endereço de e-mail",
-    "Password" : "Senha",
-    "Manual configuration" : "Configuração manual",
-    "IMAP Host" : "Host IMAP",
-    "IMAP security" : "Segurança IMAP",
-    "None" : "Não",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "Porto IMAP",
-    "IMAP User" : "Usuário IMAP",
-    "IMAP Password" : "Senha IMAP",
-    "SMTP Host" : "Host SMTP",
-    "SMTP security" : "Segurança SMTP",
-    "SMTP Port" : "Porto SMTP",
-    "SMTP User" : "Usuário SMTP",
-    "SMTP Password" : "Senha SMTP",
-    "Connect" : "Conectar",
-    "from" : "de",
-    "to" : "para",
-    "cc" : "cc",
-    "bcc" : "cco",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Observe que o e-mail veio de um endereço no-reply então sua resposta provavelmente não será lida.",
-    "Subject" : "Assunto",
-    "Save all to Files" : "Salvar tudo para Arquivos",
-    "Add mail account" : "Adicionar conta de e-mail",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar e avatares para favicon",
-    "No search results for" : "Nenhum resultado de busca para",
-    "The images have been blocked to protect your privacy." : "As imagens foram bloqueadas para proteger sua privacidade",
-    "Show images from this sender" : "Mostre imagens desse remetente",
-    "Forward" : "Encaminhar",
-    "No messages in this folder" : "Sem mensagens nesta pasta",
-    "Upload attachment" : "Enviar anexo",
-    "Add attachment from Files" : "Adicionar anexo a partir de arquivos",
-    "Import into calendar" : "Importar para o calendário",
-    "Download attachment" : "Baixar anexo",
-    "Save to Files" : "Salvar para arquivos"
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mensagem \nde {from}","%n novas mensagens \nde {from}"],
+    "Nextcloud Mail" : "E-mail Nextcloud",
+    "All inboxes" : "Todas as caixas de entrada",
+    "Could not load {tag}{name}{endtag}" : "Não foi possível carregar {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Ocorreu um problema ao carregar {tag}{name}{endtag}",
+    "Could not load the desired message" : "Não foi possível carregar a mensagem desejada",
+    "Could not load the message" : "Não foi possível carregar a mensagem",
+    "Error loading message" : "Erro carregando mensagem",
+    "Forwarding to %s" : "Encaminhando para %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se você não for redirecionado automaticamente em alguns segundos",
+    "Redirect" : "Redirecionar",
+    "The link leads to %s" : "O link leva a %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se você não quiser visitar essa página, você pode retornar ao <a href=\"%s\">e-mail</a>.",
+    "Continue to %s" : "Continue para %s"
 },
 "nplurals=2; plural=(n > 1);");
