@@ -2,56 +2,6 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Пошта",
-    "Loading accounts" : "Учитавам налоге",
-    "Error while loading the accounts." : "Грешка при учитавању налога.",
-    "Can not load this folder." : "Не могу да учитам фасциклу.",
-    "Searching for {query}" : "Тражим по упиту {query}",
-    "Error while deleting message." : "Грешка при брисању поруке.",
-    "Forwarded message" : "Прослеђена порука",
-    "Choose a folder to store the attachment in" : "Изаберите фасциклу за смештање прилога",
-    "Attachments saved to Files." : "Прилози сачувани у фајловима.",
-    "Attachment saved to Files." : "Прилог сачуван у фајловима.",
-    "Error while saving attachments to Files." : "Грешка при упису прилога у фајлове.",
-    "Error while saving attachment to Files." : "Грешка при упису прилога у фајлове.",
-    "Message flag could not be set." : "Не могу да ставим заставицу на поруку.",
-    "Could not move message." : "Не могу да померим поруку.",
-    "Invalid account" : "Неисправан налог",
-    "Invalid folder" : "Неисправна фасцикла",
-    "Error while creating the account: " : "Грешка приликом креирања налога:",
-    "Unknown error" : "Непозната грешка",
-    "Error while updating the account: " : "Грешка приликом ажурирања налога:",
-    "All inboxes" : "Сва сандучета",
-    "you" : "Ви",
-    "Send message to {email}" : "Пошаљи поруку на {email}",
-    "Could not load {tag}{name}{endtag}" : "Не могу да учитам {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Десио се проблем приликом учитавања {tag}{name}{endtag}",
-    "Could not load your message" : "Неуспело учитавање поруке",
-    "Could not load the desired message" : "Неуспело учитавање жељене поруке",
-    "Could not load the message" : "Неуспело учитавање поруке",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n порука\nод {from}","%n поруке\nод {from}","%n порука\nод {from}"],
-    "Nextcloud Mail" : "Некстклауд Пошта",
-    "Save" : "Сачувај",
-    "Saved" : "Сачувано",
-    "Show all folders" : "Прикажи све фасцикле",
-    "Collapse folders" : "Сажми фасцикле",
-    "Error while deleting account." : "Грешка при брисању налога.",
-    "Choose a file to add as attachment" : "Изаберите фајл за прилог",
-    "An error occurred while uploading {fname}" : "Грешка приликом отпремања {fname}",
-    "Reply" : "Одговори",
-    "Send" : "Пошаљи",
-    "Sending …" : "Шаљем …",
-    "Message sent!" : "Порука послата!",
-    "Server error" : "Грешка на серверу",
-    "An unknown error occurred" : "Десила се непозната грешка",
-    "Opening HTML drafts is not supported yet." : "Отварање HTML нацрта још није подржано.",
-    "No writable calendars found" : "Нема календара у који је могуће писање",
-    "Error while importing the calendar event" : "Грешка приликом увоза догађаја из календара",
-    "Error while downloading calendar event" : "Грешка приликом скидања догађаја из календара",
-    "& others" : "и осталих",
-    "Error while loading messages." : "Грешка при учитавању порука.",
-    "Error while refreshing messages." : "Грешка приликом освежавања порука.",
-    "Setting up your account" : "Подешавање Вашег налога",
     "Inbox" : "Долазне",
     "Sent" : "Послате",
     "Drafts" : "Недовршене",
@@ -66,25 +16,83 @@ OC.L10N.register(
     "Delete permanently" : "Обриши заувек",
     "IMAP web client" : "IMAP веб клијент",
     "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Једноставан клијент е-поште који се повезује са Вашим сервером е-поште преко IMAP-а и SMTP-а.",
-    "Error loading message" : "Грешка при учитавању поруке",
-    "Settings" : "Подешавања",
-    "Forwarding to %s" : "Прослеђивање на %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Кликните овде ако нисте аутоматски преусмерени у наредних неколико секунди.",
-    "Redirect" : "Преусмеравање",
-    "The link leads to %s" : "Веза води на %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желите да посетите ту страну, можете се вратити на <a href=\"%s\">Пошту</a>.",
-    "Continue to %s" : "Настави на %s",
-    "Delete account" : "Обриши налог",
-    "Try again" : "Покушајте поново",
-    "New message" : "Нова порука",
-    "Account Settings" : "Поставке налога",
-    "Aliases" : "Алијаси",
-    "Mail address" : "Адреса поште",
-    "Display Name" : "Име за приказ",
-    "Account" : "Налог",
-    "Toggle read" : "Укључи/искључи прочитано",
-    "Delete" : "Избриши",
+    "Auto" : "Аутоматски",
+    "Name" : "Име",
+    "Mail Address" : "Адреса е-поште",
+    "Password" : "Лозинка",
+    "Manual" : "Ручно",
+    "IMAP Settings" : "IMAP поставке",
+    "IMAP Host" : "IMAP домаћин",
+    "IMAP Security" : "IMAP безбедност",
+    "None" : "Ниједна",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "IMAP порт",
+    "IMAP User" : "IMAP корисничко име",
+    "IMAP Password" : "IMAP лозинка",
+    "SMTP Settings" : "SMTP поставке",
+    "SMTP Host" : "SMTP домаћин",
+    "SMTP Security" : "SMTP безбедност",
+    "SMTP Port" : "SMTP порт",
+    "SMTP User" : "SMTP корисничко име",
+    "SMTP Password" : "SMTP лозинка",
+    "Save" : "Сачувај",
+    "Connect" : "Повежи се",
+    "Add mail account" : "Додај налог е-поште",
+    "Use Gravatar and favicon avatars" : "Користи Граватар и аватаре favicon-а",
     "Keyboard shortcuts" : "Пречице на тастатури",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Тражите начин да шифрујете Вашу пошту? Инсталирајте Mailvelope есктензију за веб читаче!",
+    "from" : "од",
+    "to" : "за",
+    "+ cc/bcc" : "+ cc/bcc",
+    "cc" : "индиго копија",
+    "bcc" : "невидљива индиго копија",
+    "Subject" : "Наслов",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Ова е-пошта је стигла са адресе на којој има \"noreply\", што\tзначи да вероватно неће бити прочитана ако одговорите на њу.",
+    "Message …" : "Порука …",
+    "Saving draft …" : "Чувам нацрт …",
+    "Draft saved" : "Нацрт сачуван",
+    "Uploading attachments …" : "Отпремам прилоге …",
+    "Sending …" : "Шаљем …",
+    "Error sending your message" : "Грешка приликом слања поруке",
+    "Go back" : "Иди назад",
+    "Retry" : "Покушај поново",
+    "Message sent!" : "Порука послата!",
+    "Reply sent!" : "Одговор послат!",
+    "Write another message" : "Напиши још једну поруку",
+    "Send" : "Пошаљи",
+    "Uploading {percent}% …" : "Отпремам {percent}% …",
+    "Upload attachment" : "Закачи прилог",
+    "Add attachment from Files" : "Додај прилог из фајлова",
+    "Choose a file to add as attachment" : "Изаберите фајл за прилог",
+    "No messages in this folder" : "Нема порука у овој фасцикли",
+    "Draft: " : "Нацрт: ",
+    "Mark read" : "Означи као прочитано",
+    "Mark unread" : "Означи као непрочитано",
+    "Delete" : "Избриши",
+    "Report this bug" : "Пријави ову грешку",
+    "Loading messages" : "Учитавам поруке",
+    "Not found" : "Није нађено",
+    "Could not load your message" : "Неуспело учитавање поруке",
+    "Import into calendar" : "Увези у календар",
+    "Download attachment" : "Скини прилог",
+    "Save to Files" : "Сачувај у фајлове",
+    "Choose a folder to store the attachment in" : "Изаберите фасциклу за смештање прилога",
+    "Save all to Files" : "Сачувај све у фајлове",
+    "Choose a folder to store the attachments in" : "Одаберите фасциклу за смештање прилога",
+    "The images have been blocked to protect your privacy." : "Слике су блокиране да заштите Вашу приватност.",
+    "Show images from this\tsender" : "Прикажи слике од овог\tпошаљиоца",
+    "New message" : "Нова порука",
+    "Settings" : "Подешавања",
+    "Edit" : "Измени",
+    "Show all folders" : "Прикажи све фасцикле",
+    "Collapse folders" : "Сажми фасцикле",
+    "Could not load your draft" : "Не могу да учитам нацрт",
+    "No message selected" : "Није одабрана ниједна порука",
+    "Signature" : "Потпис",
+    "A signature will be added to the text of new and response messages." : "Потпис ће бити додат на текст свих нових порука и одговора.",
+    "Account Settings" : "Поставке налога",
+    "Mail server" : "Сервер е-поште",
     "Speed up your Mail experience with these quick shortcuts." : "Убрзајте рад са Поштом са овим брзим пречицама.",
     "Compose new message" : "Напиши нову поруку",
     "Newer message" : "Новије поруке",
@@ -94,41 +102,20 @@ OC.L10N.register(
     "Search" : "Претражи",
     "Refresh" : "Освежи",
     "Connect your mail account" : "Повежи се на налог е-поште",
-    "Name" : "Име",
-    "Mail Address" : "Адреса е-поште",
-    "Password" : "Лозинка",
-    "Manual configuration" : "Ручна конфигурација",
-    "IMAP Host" : "IMAP домаћин",
-    "IMAP security" : "Тип IMAP безбедности",
-    "None" : "Ниједна",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "IMAP порт",
-    "IMAP User" : "IMAP корисничко име",
-    "IMAP Password" : "IMAP лозинка",
-    "SMTP Host" : "SMTP домаћин",
-    "SMTP security" : "Тип SMTP безбедности",
-    "SMTP Port" : "SMTP порт",
-    "SMTP User" : "SMTP корисничко име",
-    "SMTP Password" : "SMTP лозинка",
-    "Connect" : "Повежи се",
-    "from" : "од",
-    "to" : "за",
-    "cc" : "индиго копија",
-    "bcc" : "невидљива индиго копија",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Ова е-пошта је стигла са адресе на којој има \"noreply\", што значи да вероватно неће бити прочитана ако одговорите на њу.",
-    "Subject" : "Наслов",
-    "Save all to Files" : "Сачувај све у фајлове",
-    "Add mail account" : "Додај налог е-поште",
-    "Use Gravatar and favicon avatars" : "Користи Граватар и аватаре favicon-а",
-    "No search results for" : "Нема резултата претраге",
-    "The images have been blocked to protect your privacy." : "Слике су блокиране да заштите Вашу приватност.",
-    "Show images from this sender" : "Прикажи слике од пошаљиоца",
-    "Forward" : "Проследи",
-    "No messages in this folder" : "Нема порука у овој фасцикли",
-    "Upload attachment" : "Закачи прилог",
-    "Add attachment from Files" : "Додај прилог из фајлова",
-    "Import into calendar" : "Увези у календар",
-    "Download attachment" : "Скини прилог",
-    "Save to Files" : "Сачувај у фајлове"
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n порука\nод {from}","%n поруке\nод {from}","%n порука\nод {from}"],
+    "Nextcloud Mail" : "Некстклауд Пошта",
+    "All inboxes" : "Сва сандучета",
+    "Could not load {tag}{name}{endtag}" : "Не могу да учитам {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Десио се проблем приликом учитавања {tag}{name}{endtag}",
+    "Could not load the desired message" : "Неуспело учитавање жељене поруке",
+    "Could not load the message" : "Неуспело учитавање поруке",
+    "Error loading message" : "Грешка при учитавању поруке",
+    "Forwarding to %s" : "Прослеђивање на %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Кликните овде ако нисте аутоматски преусмерени у наредних неколико секунди.",
+    "Redirect" : "Преусмеравање",
+    "The link leads to %s" : "Веза води на %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желите да посетите ту страну, можете се вратити на <a href=\"%s\">Пошту</a>.",
+    "Continue to %s" : "Настави на %s"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
