@@ -2,56 +2,6 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "E-post",
-    "Loading accounts" : "Laddar konton",
-    "Error while loading the accounts." : "Fel vid inläsning av konton.",
-    "Can not load this folder." : "Kan inte ladda denna mapp.",
-    "Searching for {query}" : "Söker efter {query}",
-    "Error while deleting message." : "Fel vid radering av  meddelande.",
-    "Forwarded message" : "Vidarebefordrat meddelande",
-    "Choose a folder to store the attachment in" : "Välj en mapp att spara den bifogade filen i",
-    "Attachments saved to Files." : "Bilagorna har sparats till filer.",
-    "Attachment saved to Files." : "Bilagan har sparats till filer.",
-    "Error while saving attachments to Files." : "Ett fel uppstod när bilagorna sparades till filer.",
-    "Error while saving attachment to Files." : "Ett fel uppstod när bilagan sparades till filer.",
-    "Message flag could not be set." : "Meddelandeflaggan kunde inte ställas in.",
-    "Could not move message." : "Kunde inte flytta meddelande.",
-    "Invalid account" : "Felaktigt konto",
-    "Invalid folder" : "Felaktig mapp",
-    "Error while creating the account: " : "Fel när kontot skulle skapas:",
-    "Unknown error" : "Okänt fel",
-    "Error while updating the account: " : "Fel medan kontot uppdaterades:",
-    "All inboxes" : "alla inkorgar",
-    "you" : "du",
-    "Send message to {email}" : "Skicka meddelande till {email}",
-    "Could not load {tag}{name}{endtag}" : "Kunde inte ladda {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Det blev ett problem när vi skulle ladda {tag}{name}{endtag}",
-    "Could not load your message" : "Kunde inte ladda ditt meddelande",
-    "Could not load the desired message" : "Kunde inte ladda önskat meddelande",
-    "Could not load the message" : "Kunde inte ladda meddelandet",
-    "{from}\n{subject}" : "{från}\n{ämne}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nytt meddelande \nfrån {from}","%n nya meddelanden \nfrån {from}"],
-    "Nextcloud Mail" : "Nextcloud Mail",
-    "Save" : "Spara",
-    "Saved" : "Sparad",
-    "Show all folders" : "Visa alla kataloger",
-    "Collapse folders" : "Dölj mappar",
-    "Error while deleting account." : "Fel vid radering av konto.",
-    "Choose a file to add as attachment" : "Välj en fil att lägga som bilaga",
-    "An error occurred while uploading {fname}" : "Ett fel inträffade när {fname} laddades upp",
-    "Reply" : "Svara",
-    "Send" : "Skicka",
-    "Sending …" : "Skickar ...",
-    "Message sent!" : "Meddelande skickat!",
-    "Server error" : "Serverfel",
-    "An unknown error occurred" : "Ett okänt fel uppstod",
-    "Opening HTML drafts is not supported yet." : "Att öppna HTML-utkast stöds inte än.",
-    "No writable calendars found" : "Inga skrivbara kalendrar hittade",
-    "Error while importing the calendar event" : "Fel vid import av kalenderhändelse",
-    "Error while downloading calendar event" : "Fel vid nedladdning av kalenderhändelse",
-    "& others" : "& andra",
-    "Error while loading messages." : "Fel vid inläsning av meddelanden.",
-    "Error while refreshing messages." : "Fel när meddelande uppdaterades.",
-    "Setting up your account" : "Sätter upp ditt konto",
     "Inbox" : "Inkorg",
     "Sent" : "Skickat",
     "Drafts" : "Utkast",
@@ -66,25 +16,82 @@ OC.L10N.register(
     "Delete permanently" : "Radera permanent",
     "IMAP web client" : "IMAP webbklient",
     "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Lättanvänd e-postklient som ansluter till din e-postserver via IMAP och SMTP.",
-    "Error loading message" : "Fel vid inläsning av meddelande",
-    "Settings" : "Inställningar",
-    "Forwarding to %s" : "Vidarebefordrar till %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Klicka här om du inte blir omdirigerad inom några sekunder.",
-    "Redirect" : "Omdirigera",
-    "The link leads to %s" : "Länken pekar mot %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Om du inte vill besöka denna sidan så kan du gå tillbaka till <a href=\"%s\">Mail</a>",
-    "Continue to %s" : "Fortsätt till %s",
-    "Delete account" : "Radera konto",
-    "Try again" : "Försök igen",
-    "New message" : "Nytt meddelande",
-    "Account Settings" : "Kontoinställningar",
-    "Aliases" : "Alias",
-    "Mail address" : "E-postadress",
-    "Display Name" : "Visningsnamn",
-    "Account" : "Konto",
-    "Toggle read" : "Växla läst",
-    "Delete" : "Ta bort",
+    "Auto" : "Auto",
+    "Name" : "Namn",
+    "Mail Address" : "E-postadress",
+    "Password" : "Lösenord",
+    "Manual" : "Manuell",
+    "IMAP Settings" : "IMAP-inställningar",
+    "IMAP Host" : "IMAP-värd",
+    "IMAP Security" : "IMAP-säkerhet",
+    "None" : "Ingen",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "IMAP-port",
+    "IMAP User" : "Användare",
+    "IMAP Password" : "IMAP-lösenord",
+    "SMTP Settings" : "SMTP-inställningar",
+    "SMTP Host" : "SMTP Host",
+    "SMTP Security" : "SMTP-säkerhet",
+    "SMTP Port" : "SMTP-port",
+    "SMTP User" : "SMTP-användare",
+    "SMTP Password" : "SMTP-lösenord",
+    "Save" : "Spara",
+    "Connect" : "Anslut",
+    "Add mail account" : "Lägg till e-postkonto",
+    "Use Gravatar and favicon avatars" : "Använd Gravatar och favicon avatarer",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Letar du efter ett sätt att kryptera dina e-postmeddelanden? Installera webbläsar-tillägget Mailvelope!",
+    "from" : "Från",
+    "to" : "till",
+    "cc" : "cc",
+    "bcc" : "bcc",
+    "Subject" : "Ämne",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Observera att avsändaren är en noreply-adress så\tditt svar kommer antagligen inte att läsas.",
+    "Message …" : "Meddelande ...",
+    "Saving draft …" : "Sparar utkast ...",
+    "Draft saved" : "Utkast sparat",
+    "Uploading attachments …" : "Laddar upp bilagor ...",
+    "Sending …" : "Skickar ...",
+    "Error sending your message" : "Ett fel inträffade när ditt meddelande skulle skickas",
+    "Go back" : "Gå tillbaka",
+    "Retry" : "Försök igen",
+    "Message sent!" : "Meddelande skickat!",
+    "Reply sent!" : "Svar skickat!",
+    "Write another message" : "Skriv ett annat meddelande",
+    "Send" : "Skicka",
+    "Uploading {percent}% …" : "Laddar upp {percent}% …",
+    "Upload attachment" : "Ladda upp bilaga",
+    "Add attachment from Files" : "Lägg till bilaga från Filer",
+    "Choose a file to add as attachment" : "Välj en fil att lägga som bilaga",
+    "No messages in this folder" : "Inga meddelanden i denna mapp",
+    "Draft: " : "Utkast:",
+    "Mark read" : "Markera som läst",
+    "Mark unread" : "Markera som oläst",
+    "Delete" : "Ta bort",
+    "Report this bug" : "Rapportera detta fel",
+    "Loading messages" : "Laddar meddelanden",
+    "Not found" : "Hittades inte",
+    "Could not load your message" : "Kunde inte ladda ditt meddelande",
+    "Import into calendar" : "Importera till kalender",
+    "Download attachment" : "Ladda ned bilaga",
+    "Save to Files" : "Spara fil till dina filer",
+    "Choose a folder to store the attachment in" : "Välj en mapp att spara den bifogade filen i",
+    "Save all to Files" : "Spara allt till dina filer",
+    "Choose a folder to store the attachments in" : "Välj en mapp att spara bifogade filer i",
+    "The images have been blocked to protect your privacy." : "Bilderna har blockerats av säkerhetsskäl.",
+    "Show images from this\tsender" : "Visa bilder från denna\tavsändare",
+    "New message" : "Nytt meddelande",
+    "Settings" : "Inställningar",
+    "Edit" : "Redigera",
+    "Show all folders" : "Visa alla kataloger",
+    "Collapse folders" : "Dölj mappar",
+    "Could not load your draft" : "Kunde inte ladda ditt utkast",
+    "No message selected" : "Inget meddelande valt",
+    "Signature" : "Signatur",
+    "A signature will be added to the text of new and response messages." : "En signatur läggs till i texten till nya och svarsmeddelanden.",
+    "Account Settings" : "Kontoinställningar",
+    "Mail server" : "E-postserver",
     "Speed up your Mail experience with these quick shortcuts." : "Snabba upp din E-post-upplevelse med dessa genvägar.",
     "Compose new message" : "Skapa nytt meddelande",
     "Newer message" : "Nyare meddelande",
@@ -94,41 +101,20 @@ OC.L10N.register(
     "Search" : "Sök",
     "Refresh" : "Uppdatera",
     "Connect your mail account" : "Anslut ditt e-postkonto",
-    "Name" : "Namn",
-    "Mail Address" : "E-postadress",
-    "Password" : "Lösenord",
-    "Manual configuration" : "Manuellt konfiguration",
-    "IMAP Host" : "IMAP-värd",
-    "IMAP security" : "IMAP säkerhet",
-    "None" : "Ingen",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "IMAP-port",
-    "IMAP User" : "Användare",
-    "IMAP Password" : "IMAP-lösenord",
-    "SMTP Host" : "SMTP Host",
-    "SMTP security" : "SMTP-säkerhet",
-    "SMTP Port" : "SMTP-port",
-    "SMTP User" : "SMTP-användare",
-    "SMTP Password" : "SMTP-lösenord",
-    "Connect" : "Anslut",
-    "from" : "Från",
-    "to" : "till",
-    "cc" : "cc",
-    "bcc" : "bcc",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Observera att avsändaren är en noreply-adress så ditt svar kommer antagligen inte att läsas.",
-    "Subject" : "Ämne",
-    "Save all to Files" : "Spara allt till dina filer",
-    "Add mail account" : "Lägg till e-postkonto",
-    "Use Gravatar and favicon avatars" : "Använd Gravatar och favicon avatarer",
-    "No search results for" : "Inga sökresultat hittades för",
-    "The images have been blocked to protect your privacy." : "Bilderna har blockerats av säkerhetsskäl.",
-    "Show images from this sender" : "Visa bilder från denna avsändare",
-    "Forward" : "Vidarebefodra",
-    "No messages in this folder" : "Inga meddelanden i denna mapp",
-    "Upload attachment" : "Ladda upp bilaga",
-    "Add attachment from Files" : "Lägg till bilaga från Filer",
-    "Import into calendar" : "Importera till kalender",
-    "Download attachment" : "Ladda ned bilaga",
-    "Save to Files" : "Spara fil till dina filer"
+    "{from}\n{subject}" : "{från}\n{ämne}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nytt meddelande \nfrån {from}","%n nya meddelanden \nfrån {from}"],
+    "Nextcloud Mail" : "Nextcloud Mail",
+    "All inboxes" : "alla inkorgar",
+    "Could not load {tag}{name}{endtag}" : "Kunde inte ladda {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Det blev ett problem när vi skulle ladda {tag}{name}{endtag}",
+    "Could not load the desired message" : "Kunde inte ladda önskat meddelande",
+    "Could not load the message" : "Kunde inte ladda meddelandet",
+    "Error loading message" : "Fel vid inläsning av meddelande",
+    "Forwarding to %s" : "Vidarebefordrar till %s",
+    "Click here if you are not automatically redirected within the next few seconds." : "Klicka här om du inte blir omdirigerad inom några sekunder.",
+    "Redirect" : "Omdirigera",
+    "The link leads to %s" : "Länken pekar mot %s",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Om du inte vill besöka denna sidan så kan du gå tillbaka till <a href=\"%s\">Mail</a>",
+    "Continue to %s" : "Fortsätt till %s"
 },
 "nplurals=2; plural=(n != 1);");
