@@ -2,56 +2,6 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Posta",
-    "Loading accounts" : "Hesaplar yükleniyor",
-    "Error while loading the accounts." : "Hesaplar yüklenirken sorun çıktı.",
-    "Can not load this folder." : "Bu klasör yüklenemedi.",
-    "Searching for {query}" : "{query} aranıyor",
-    "Error while deleting message." : "İleti silinirken sorun çıktı.",
-    "Forwarded message" : "İletilmiş ileti",
-    "Choose a folder to store the attachment in" : "Ek dosyasının depolanacağı bir klasör seçin",
-    "Attachments saved to Files." : "Ek Dosya Dosyalara kaydedildi.",
-    "Attachment saved to Files." : "Ek Dosya Dosyalara kaydedildi.",
-    "Error while saving attachments to Files." : "Ek dosyalar Dosyalara kaydedilirken sorun çıktı.",
-    "Error while saving attachment to Files." : "Ek dosya Dosyalara kaydedilirken sorun çıktı.",
-    "Message flag could not be set." : "İleti işareti ayarlanamadı.",
-    "Could not move message." : "İleti taşınamadı.",
-    "Invalid account" : "Hesap geçersiz",
-    "Invalid folder" : "Klasör geçersiz",
-    "Error while creating the account: " : "Hesap eklenirken sorun çıktı:",
-    "Unknown error" : "Bilinmeyen bir sorun çıktı",
-    "Error while updating the account: " : "Hesap güncellenirken sorun çıktı:",
-    "All inboxes" : "Tüm gelen kutuları",
-    "you" : "siz",
-    "Send message to {email}" : "{email} adresine ileti gönder",
-    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} yüklenemedi",
-    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag} yüklenirken bir sorun çıktı",
-    "Could not load your message" : "İletiniz yüklenemedi",
-    "Could not load the desired message" : "İstenilen ileti yüklenemedi",
-    "Could not load the message" : "İleti yüklenemedi",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n yeni ileti\ngönderen {from}","%n yeni ileti\ngönderen {from}"],
-    "Nextcloud Mail" : "Nextcloud Posta",
-    "Save" : "Kaydet",
-    "Saved" : "Kaydedildi",
-    "Show all folders" : "Tüm klasörleri görüntüle",
-    "Collapse folders" : "Klasörleri daralt",
-    "Error while deleting account." : "Hesap silinirken sorun çıktı.",
-    "Choose a file to add as attachment" : "Eklenecek ek dosyasını seçin",
-    "An error occurred while uploading {fname}" : "{fname} yüklenirken bir sorun çıktı",
-    "Reply" : "Yanıtla",
-    "Send" : "Gönder",
-    "Sending …" : "Gönderiliyor...",
-    "Message sent!" : "İleti gönderildi!",
-    "Server error" : "Sunucu sorunu",
-    "An unknown error occurred" : "Bilinmeyen bir sorun çıktı",
-    "Opening HTML drafts is not supported yet." : "HTML taslaklarının açılması henüz desteklenmiyor.",
-    "No writable calendars found" : "Yazılabilecek bir takvim bulunamadı",
-    "Error while importing the calendar event" : "Takvim etkinliği içe aktarılırken sorun çıktı",
-    "Error while downloading calendar event" : "Takvim etkinliği indirilirken sorun çıktı",
-    "& others" : "ve diğer",
-    "Error while loading messages." : "İletiler yüklenirken sorun çıktı.",
-    "Error while refreshing messages." : "İletiler yenilenirken sorun çıktı.",
-    "Setting up your account" : "Hesabınız ayarlanıyor",
     "Inbox" : "Gelen Kutusu",
     "Sent" : "Gönderilenler",
     "Drafts" : "Taslaklar",
@@ -66,25 +16,82 @@ OC.L10N.register(
     "Delete permanently" : "Kalıcı olarak sil",
     "IMAP web client" : "IMAP web istemcisi",
     "Easy to use email client which connects to your mail server via IMAP and SMTP." : "E-posta sunucunuz ile IMAP ve SMTP bağlantısı kuran kullanımı kolay bir e-posta istemcisi.",
-    "Error loading message" : "İleti yüklenirken sorun çıktı",
-    "Settings" : "Ayarlar",
-    "Forwarding to %s" : "%s adresine iletiliyor",
-    "Click here if you are not automatically redirected within the next few seconds." : "Bir kaç saniye içinde otomatik olarak yönlendirilmezseniz buraya tıklayın.",
-    "Redirect" : "Yönlendir",
-    "The link leads to %s" : "Bağlantı %s adresine gidiyor",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Bu sayfayı ziyaret etmek istemiyorsanız, <a href=\"%s\">posta uygulamasına</a> geri dönebilirsiniz.",
-    "Continue to %s" : "%s sayfasına geç",
-    "Delete account" : "Hesabı sil",
-    "Try again" : "Yeniden deneyin",
-    "New message" : "Yeni ileti",
-    "Account Settings" : "Hesap Ayarları",
-    "Aliases" : "Kısaltmalar",
-    "Mail address" : "Posta adresi",
-    "Display Name" : "Görüntülenecek Ad",
-    "Account" : "Hesap",
-    "Toggle read" : "Okunmuş işaretini değiştir",
-    "Delete" : "Sil",
+    "Auto" : "Otomatik",
+    "Name" : "Ad",
+    "Mail Address" : "Posta Adresi",
+    "Password" : "Parola",
+    "Manual" : "El İle",
+    "IMAP Settings" : "IMAP Ayarları",
+    "IMAP Host" : "IMAP Sunucusu",
+    "IMAP Security" : "IMAP Güvenliği",
+    "None" : "Yok",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "IMAP Kapı Numarası",
+    "IMAP User" : "IMAP Kullanıcı Adı",
+    "IMAP Password" : "IMAP Parolası",
+    "SMTP Settings" : "SMTP Ayarları",
+    "SMTP Host" : "SMTP Sunucusu",
+    "SMTP Security" : "SMTP Güvenliği",
+    "SMTP Port" : "SMTP Kapı Numarası",
+    "SMTP User" : "SMTP Kullanıcı Adı",
+    "SMTP Password" : "SMTP Parolası",
+    "Save" : "Kaydet",
+    "Connect" : "Bağlan",
+    "Add mail account" : "Posta hesabi ekle",
+    "Use Gravatar and favicon avatars" : "Gravatar ve favicon avatarları kullanılsın",
     "Keyboard shortcuts" : "Tuş takımı kısayolları",
+    "from" : "kimden",
+    "to" : "kime",
+    "+ cc/bcc" : "+ Kopya/Gizli Kopya",
+    "cc" : "kopya",
+    "bcc" : "gizli kopya",
+    "Subject" : "Konu",
+    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "E-posta noreply adresinden gönderildiğinden yanıtınızın okunmayabileceğini unutmayın",
+    "Message …" : "İleti …",
+    "Saving draft …" : "Taslak kaydediliyor …",
+    "Draft saved" : "Taslak kaydedildi",
+    "Uploading attachments …" : "Ek dosya yükleniyor …",
+    "Sending …" : "Gönderiliyor...",
+    "Error sending your message" : "İletiniz gönderilirken sorun çıktı",
+    "Go back" : "Geri Dön",
+    "Retry" : "Yeniden Dene",
+    "Message sent!" : "İleti gönderildi!",
+    "Reply sent!" : "Yanıt gönderildi!",
+    "Write another message" : "Başka bir ileti gönder",
+    "Send" : "Gönder",
+    "Uploading {percent}% …" : "Yükleniyor %{percent} …",
+    "Upload attachment" : "Ek dosya yükle",
+    "Add attachment from Files" : "Dosyalardan ek dosya ekle",
+    "Choose a file to add as attachment" : "Eklenecek ek dosyasını seçin",
+    "No messages in this folder" : "Bu klasörde herhangi bir ileti yok",
+    "Draft: " : "Taslak",
+    "Mark read" : "Okunmuş olarak işaretle",
+    "Mark unread" : "Okunmamış olarak işaretle",
+    "Delete" : "Sil",
+    "Report this bug" : "Bu hatayı bildirin",
+    "Loading messages" : "İletiler yükleniyor",
+    "Not found" : "Bulunamadı",
+    "Could not load your message" : "İletiniz yüklenemedi",
+    "Import into calendar" : "Şu takvimin içine aktar",
+    "Download attachment" : "Ek dosyayı indir",
+    "Save to Files" : "Dosyalara Kaydet",
+    "Choose a folder to store the attachment in" : "Ek dosyasının depolanacağı bir klasör seçin",
+    "Save all to Files" : "Tümünü dosyalara kaydet",
+    "Choose a folder to store the attachments in" : "Ek dosyalarının kaydedileceği bir klasör seçin",
+    "The images have been blocked to protect your privacy." : "Gizliliğinizi korumak için görsellerin görüntülenmesi engellendi.",
+    "Show images from this\tsender" : "Bu gönderenden gelen görseller görüntülensin",
+    "New message" : "Yeni ileti",
+    "Settings" : "Ayarlar",
+    "Edit" : "Düzenle",
+    "Show all folders" : "Tüm klasörleri görüntüle",
+    "Collapse folders" : "Klasörleri daralt",
+    "Could not load your draft" : "Taslağınız yüklenemedi",
+    "No message selected" : "Herhangi bir ileti seçilmemiş",
+    "Signature" : "İmza",
+    "A signature will be added to the text of new and response messages." : "Yeni ve yanıt iletilerine eklenecek imza.",
+    "Account Settings" : "Hesap Ayarları",
+    "Mail server" : "E-posta Sunucusu",
     "Speed up your Mail experience with these quick shortcuts." : "Kısayol tuşlarını kullanarak e-posta deneyiminizi hızlandırabilirsiniz.",
     "Compose new message" : "Yeni ileti gönder",
     "Newer message" : "Daha yeni ileti",
@@ -94,41 +101,20 @@ OC.L10N.register(
     "Search" : "Arama",
     "Refresh" : "Yenlle",
     "Connect your mail account" : "Posta hesabınızı bağlayın",
-    "Name" : "Ad",
-    "Mail Address" : "Posta Adresi",
-    "Password" : "Parola",
-    "Manual configuration" : "El ile yapılandırma",
-    "IMAP Host" : "IMAP Sunucusu",
-    "IMAP security" : "IMAP Güvenliği",
-    "None" : "Yok",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "IMAP Kapı Numarası",
-    "IMAP User" : "IMAP Kullanıcı Adı",
-    "IMAP Password" : "IMAP Parolası",
-    "SMTP Host" : "SMTP Sunucusu",
-    "SMTP security" : "SMTP Güvenliği",
-    "SMTP Port" : "SMTP Kapı Numarası",
-    "SMTP User" : "SMTP Kullanıcı Adı",
-    "SMTP Password" : "SMTP Parolası",
-    "Connect" : "Bağlan",
-    "from" : "kimden",
-    "to" : "kime",
-    "cc" : "kopya",
-    "bcc" : "gizli kopya",
-    "Note that the mail came from a noreply address so your reply will probably not be read." : "Posta noreply adresinden gönderildiğinden yanıtınızın okunmayabileceğini unutmayın",
-    "Subject" : "Konu",
-    "Save all to Files" : "Tümünü dosyalara kaydet",
-    "Add mail account" : "Posta hesabi ekle",
-    "Use Gravatar and favicon avatars" : "Gravatar ve favicon avatarları kullanılsın",
-    "No search results for" : "Şu aramadan bir sonuç alınamadı",
-    "The images have been blocked to protect your privacy." : "Gizliliğinizi korumak için görsellerin görüntülenmesi engellendi.",
-    "Show images from this sender" : "Bu gönderenden gelen görseller görüntülensin",
-    "Forward" : "İlet",
-    "No messages in this folder" : "Bu klasörde herhangi bir ileti yok",
-    "Upload attachment" : "Ek dosya yükle",
-    "Add attachment from Files" : "Dosyalardan ek dosya ekle",
-    "Import into calendar" : "Şu takvimin içine aktar",
-    "Download attachment" : "Ek dosyayı indir",
-    "Save to Files" : "Dosyalara Kaydet"
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n yeni ileti\ngönderen {from}","%n yeni ileti\ngönderen {from}"],
+    "Nextcloud Mail" : "Nextcloud Posta",
+    "All inboxes" : "Tüm gelen kutuları",
+    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} yüklenemedi",
+    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag} yüklenirken bir sorun çıktı",
+    "Could not load the desired message" : "İstenilen ileti yüklenemedi",
+    "Could not load the message" : "İleti yüklenemedi",
+    "Error loading message" : "İleti yüklenirken sorun çıktı",
+    "Forwarding to %s" : "%s adresine iletiliyor",
+    "Click here if you are not automatically redirected within the next few seconds." : "Bir kaç saniye içinde otomatik olarak yönlendirilmezseniz buraya tıklayın.",
+    "Redirect" : "Yönlendir",
+    "The link leads to %s" : "Bağlantı %s adresine gidiyor",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Bu sayfayı ziyaret etmek istemiyorsanız, <a href=\"%s\">posta uygulamasına</a> geri dönebilirsiniz.",
+    "Continue to %s" : "%s sayfasına geç"
 },
 "nplurals=2; plural=(n > 1);");
